
// GENERATED FILE DO NOT EDIT
// $ xsltproc TagToVR.xsl Part6.xml > gdcmTagToVR.cxx

/*=========================================================================

  Program: GDCM (Grassroots DICOM). A DICOM library

  Copyright (c) 2006-2011 Mathieu Malaterre
  All rights reserved.
  See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "gdcmVR.h"
#include "gdcmVM.h"
#include "gdcmStaticAssert.h"

namespace gdcm {
VR::VRType GetVRFromTag( Tag const & t ) {
if( t.IsGroupLength() ) return VR::UL;
uint32_t tag = t.GetElementTag();
switch( tag ) {
case 0x00000000:return VR::UL;
case 0x00000001:return VR::UL;
case 0x00000002:return VR::UI;
case 0x00000003:return VR::UI;
case 0x00000010:return VR::SH;
case 0x00000100:return VR::US;
case 0x00000110:return VR::US;
case 0x00000120:return VR::US;
case 0x00000200:return VR::AE;
case 0x00000300:return VR::AE;
case 0x00000400:return VR::AE;
case 0x00000600:return VR::AE;
case 0x00000700:return VR::US;
case 0x00000800:return VR::US;
case 0x00000850:return VR::US;
case 0x00000860:return VR::US;
case 0x00000900:return VR::US;
case 0x00000901:return VR::AT;
case 0x00000902:return VR::LO;
case 0x00000903:return VR::US;
case 0x00001000:return VR::UI;
case 0x00001001:return VR::UI;
case 0x00001002:return VR::US;
case 0x00001005:return VR::AT;
case 0x00001008:return VR::US;
case 0x00001020:return VR::US;
case 0x00001021:return VR::US;
case 0x00001022:return VR::US;
case 0x00001023:return VR::US;
case 0x00001030:return VR::AE;
case 0x00001031:return VR::US;
case 0x00004000:return VR::LT;
case 0x00004010:return VR::LT;
case 0x00005010:return VR::SH;
case 0x00005020:return VR::SH;
case 0x00005110:return VR::LT;
case 0x00005120:return VR::LT;
case 0x00005130:return VR::CS;
case 0x00005140:return VR::CS;
case 0x00005150:return VR::CS;
case 0x00005160:return VR::CS;
case 0x00005170:return VR::IS;
case 0x00005180:return VR::CS;
case 0x00005190:return VR::CS;
case 0x000051a0:return VR::CS;
case 0x000051b0:return VR::US;
case 0x00020000:return VR::UL;
case 0x00020001:return VR::OB;
case 0x00020002:return VR::UI;
case 0x00020003:return VR::UI;
case 0x00020010:return VR::UI;
case 0x00020012:return VR::UI;
case 0x00020013:return VR::SH;
case 0x00020016:return VR::AE;
case 0x00020100:return VR::UI;
case 0x00020102:return VR::OB;
case 0x00041130:return VR::CS;
case 0x00041141:return VR::CS;
case 0x00041142:return VR::CS;
case 0x00041200:return VR::UL;
case 0x00041202:return VR::UL;
case 0x00041212:return VR::US;
case 0x00041220:return VR::SQ;
case 0x00041400:return VR::UL;
case 0x00041410:return VR::US;
case 0x00041420:return VR::UL;
case 0x00041430:return VR::CS;
case 0x00041432:return VR::UI;
case 0x00041500:return VR::CS;
case 0x00041504:return VR::UL;
case 0x00041510:return VR::UI;
case 0x00041511:return VR::UI;
case 0x00041512:return VR::UI;
case 0x0004151a:return VR::UI;
case 0x00041600:return VR::UL;
case 0x00080001:return VR::UL;
case 0x00080005:return VR::CS;
case 0x00080006:return VR::SQ;
case 0x00080008:return VR::CS;
case 0x00080010:return VR::SH;
case 0x00080012:return VR::DA;
case 0x00080013:return VR::TM;
case 0x00080014:return VR::UI;
case 0x00080016:return VR::UI;
case 0x00080018:return VR::UI;
case 0x0008001a:return VR::UI;
case 0x0008001b:return VR::UI;
case 0x00080020:return VR::DA;
case 0x00080021:return VR::DA;
case 0x00080022:return VR::DA;
case 0x00080023:return VR::DA;
case 0x00080024:return VR::DA;
case 0x00080025:return VR::DA;
case 0x0008002a:return VR::DT;
case 0x00080030:return VR::TM;
case 0x00080031:return VR::TM;
case 0x00080032:return VR::TM;
case 0x00080033:return VR::TM;
case 0x00080034:return VR::TM;
case 0x00080035:return VR::TM;
case 0x00080040:return VR::US;
case 0x00080041:return VR::LO;
case 0x00080042:return VR::CS;
case 0x00080050:return VR::SH;
case 0x00080051:return VR::SQ;
case 0x00080052:return VR::CS;
case 0x00080054:return VR::AE;
case 0x00080056:return VR::CS;
case 0x00080058:return VR::UI;
case 0x00080060:return VR::CS;
case 0x00080061:return VR::CS;
case 0x00080062:return VR::UI;
case 0x00080064:return VR::CS;
case 0x00080068:return VR::CS;
case 0x00080070:return VR::LO;
case 0x00080080:return VR::LO;
case 0x00080081:return VR::ST;
case 0x00080082:return VR::SQ;
case 0x00080090:return VR::PN;
case 0x00080092:return VR::ST;
case 0x00080094:return VR::SH;
case 0x00080096:return VR::SQ;
case 0x00080100:return VR::SH;
case 0x00080102:return VR::SH;
case 0x00080103:return VR::SH;
case 0x00080104:return VR::LO;
case 0x00080105:return VR::CS;
case 0x00080106:return VR::DT;
case 0x00080107:return VR::DT;
case 0x0008010b:return VR::CS;
case 0x0008010c:return VR::UI;
case 0x0008010d:return VR::UI;
case 0x0008010f:return VR::CS;
case 0x00080110:return VR::SQ;
case 0x00080112:return VR::LO;
case 0x00080114:return VR::ST;
case 0x00080115:return VR::ST;
case 0x00080116:return VR::ST;
case 0x00080117:return VR::UI;
case 0x00080201:return VR::SH;
case 0x00081000:return VR::AE;
case 0x00081010:return VR::SH;
case 0x00081030:return VR::LO;
case 0x00081032:return VR::SQ;
case 0x0008103e:return VR::LO;
case 0x0008103f:return VR::SQ;
case 0x00081040:return VR::LO;
case 0x00081048:return VR::PN;
case 0x00081049:return VR::SQ;
case 0x00081050:return VR::PN;
case 0x00081052:return VR::SQ;
case 0x00081060:return VR::PN;
case 0x00081062:return VR::SQ;
case 0x00081070:return VR::PN;
case 0x00081072:return VR::SQ;
case 0x00081080:return VR::LO;
case 0x00081084:return VR::SQ;
case 0x00081090:return VR::LO;
case 0x00081100:return VR::SQ;
case 0x00081110:return VR::SQ;
case 0x00081111:return VR::SQ;
case 0x00081115:return VR::SQ;
case 0x00081120:return VR::SQ;
case 0x00081125:return VR::SQ;
case 0x00081130:return VR::SQ;
case 0x00081134:return VR::SQ;
case 0x0008113a:return VR::SQ;
case 0x00081140:return VR::SQ;
case 0x00081145:return VR::SQ;
case 0x0008114a:return VR::SQ;
case 0x0008114b:return VR::SQ;
case 0x00081150:return VR::UI;
case 0x00081155:return VR::UI;
case 0x0008115a:return VR::UI;
case 0x00081160:return VR::IS;
case 0x00081161:return VR::UL;
case 0x00081162:return VR::UL;
case 0x00081163:return VR::FD;
case 0x00081164:return VR::SQ;
case 0x00081167:return VR::UI;
case 0x00081195:return VR::UI;
case 0x00081197:return VR::US;
case 0x00081198:return VR::SQ;
case 0x00081199:return VR::SQ;
case 0x00081200:return VR::SQ;
case 0x00081250:return VR::SQ;
case 0x00082110:return VR::CS;
case 0x00082111:return VR::ST;
case 0x00082112:return VR::SQ;
case 0x00082120:return VR::SH;
case 0x00082122:return VR::IS;
case 0x00082124:return VR::IS;
case 0x00082127:return VR::SH;
case 0x00082128:return VR::IS;
case 0x00082129:return VR::IS;
case 0x0008212a:return VR::IS;
case 0x00082130:return VR::DS;
case 0x00082132:return VR::LO;
case 0x00082133:return VR::SQ;
case 0x00082134:return VR::FD;
case 0x00082135:return VR::SQ;
case 0x00082142:return VR::IS;
case 0x00082143:return VR::IS;
case 0x00082144:return VR::IS;
case 0x00082200:return VR::CS;
case 0x00082204:return VR::CS;
case 0x00082208:return VR::CS;
case 0x00082218:return VR::SQ;
case 0x00082220:return VR::SQ;
case 0x00082228:return VR::SQ;
case 0x00082229:return VR::SQ;
case 0x00082230:return VR::SQ;
case 0x00082240:return VR::SQ;
case 0x00082242:return VR::SQ;
case 0x00082244:return VR::SQ;
case 0x00082246:return VR::SQ;
case 0x00082251:return VR::SQ;
case 0x00082253:return VR::SQ;
case 0x00082255:return VR::SQ;
case 0x00082256:return VR::ST;
case 0x00082257:return VR::SQ;
case 0x00082258:return VR::ST;
case 0x00082259:return VR::SQ;
case 0x0008225a:return VR::SQ;
case 0x0008225c:return VR::SQ;
case 0x00083001:return VR::SQ;
case 0x00083010:return VR::UI;
case 0x00084000:return VR::LT;
case 0x00089007:return VR::CS;
case 0x00089092:return VR::SQ;
case 0x00089121:return VR::SQ;
case 0x00089123:return VR::UI;
case 0x00089124:return VR::SQ;
case 0x00089154:return VR::SQ;
case 0x00089205:return VR::CS;
case 0x00089206:return VR::CS;
case 0x00089207:return VR::CS;
case 0x00089208:return VR::CS;
case 0x00089209:return VR::CS;
case 0x00089215:return VR::SQ;
case 0x00089237:return VR::SQ;
case 0x00089410:return VR::SQ;
case 0x00089458:return VR::SQ;
case 0x00089459:return VR::FL;
case 0x00089460:return VR::CS;
case 0x00100010:return VR::PN;
case 0x00100020:return VR::LO;
case 0x00100021:return VR::LO;
case 0x00100022:return VR::CS;
case 0x00100024:return VR::SQ;
case 0x00100030:return VR::DA;
case 0x00100032:return VR::TM;
case 0x00100040:return VR::CS;
case 0x00100050:return VR::SQ;
case 0x00100101:return VR::SQ;
case 0x00100102:return VR::SQ;
case 0x00101000:return VR::LO;
case 0x00101001:return VR::PN;
case 0x00101002:return VR::SQ;
case 0x00101005:return VR::PN;
case 0x00101010:return VR::AS;
case 0x00101020:return VR::DS;
case 0x00101021:return VR::SQ;
case 0x00101030:return VR::DS;
case 0x00101040:return VR::LO;
case 0x00101050:return VR::LO;
case 0x00101060:return VR::PN;
case 0x00101080:return VR::LO;
case 0x00101081:return VR::LO;
case 0x00101090:return VR::LO;
case 0x00102000:return VR::LO;
case 0x00102110:return VR::LO;
case 0x00102150:return VR::LO;
case 0x00102152:return VR::LO;
case 0x00102154:return VR::SH;
case 0x00102160:return VR::SH;
case 0x00102180:return VR::SH;
case 0x001021a0:return VR::CS;
case 0x001021b0:return VR::LT;
case 0x001021c0:return VR::US;
case 0x001021d0:return VR::DA;
case 0x001021f0:return VR::LO;
case 0x00102201:return VR::LO;
case 0x00102202:return VR::SQ;
case 0x00102203:return VR::CS;
case 0x00102210:return VR::CS;
case 0x00102292:return VR::LO;
case 0x00102293:return VR::SQ;
case 0x00102294:return VR::SQ;
case 0x00102295:return VR::LO;
case 0x00102296:return VR::SQ;
case 0x00102297:return VR::PN;
case 0x00102298:return VR::CS;
case 0x00102299:return VR::LO;
case 0x00104000:return VR::LT;
case 0x00109431:return VR::FL;
case 0x00120010:return VR::LO;
case 0x00120020:return VR::LO;
case 0x00120021:return VR::LO;
case 0x00120030:return VR::LO;
case 0x00120031:return VR::LO;
case 0x00120040:return VR::LO;
case 0x00120042:return VR::LO;
case 0x00120050:return VR::LO;
case 0x00120051:return VR::ST;
case 0x00120060:return VR::LO;
case 0x00120062:return VR::CS;
case 0x00120063:return VR::LO;
case 0x00120064:return VR::SQ;
case 0x00120071:return VR::LO;
case 0x00120072:return VR::LO;
case 0x00120081:return VR::LO;
case 0x00120082:return VR::LO;
case 0x00120083:return VR::SQ;
case 0x00120084:return VR::CS;
case 0x00120085:return VR::CS;
case 0x00140023:return VR::ST;
case 0x00140024:return VR::ST;
case 0x00140025:return VR::ST;
case 0x00140028:return VR::ST;
case 0x00140030:return VR::DS;
case 0x00140032:return VR::DS;
case 0x00140034:return VR::DS;
case 0x00140042:return VR::ST;
case 0x00140044:return VR::ST;
case 0x00140045:return VR::ST;
case 0x00140046:return VR::LT;
case 0x00140050:return VR::CS;
case 0x00140052:return VR::CS;
case 0x00140054:return VR::DS;
case 0x00140056:return VR::DS;
case 0x00141010:return VR::ST;
case 0x00141020:return VR::DA;
case 0x00141040:return VR::ST;
case 0x00142002:return VR::SQ;
case 0x00142004:return VR::IS;
case 0x00142006:return VR::PN;
case 0x00142008:return VR::IS;
case 0x00142012:return VR::SQ;
case 0x00142014:return VR::IS;
case 0x00142016:return VR::SH;
case 0x00142018:return VR::ST;
case 0x0014201a:return VR::CS;
case 0x0014201c:return VR::CS;
case 0x0014201e:return VR::SQ;
case 0x00142030:return VR::SQ;
case 0x00142032:return VR::SH;
case 0x00142202:return VR::IS;
case 0x00142204:return VR::SQ;
case 0x00142206:return VR::ST;
case 0x00142208:return VR::CS;
case 0x0014220a:return VR::IS;
case 0x0014220c:return VR::CS;
case 0x0014220e:return VR::CS;
case 0x00142210:return VR::OB;
case 0x00142220:return VR::SQ;
case 0x00142222:return VR::ST;
case 0x00142224:return VR::IS;
case 0x00142226:return VR::IS;
case 0x00142228:return VR::CS;
case 0x0014222a:return VR::DS;
case 0x0014222c:return VR::DS;
case 0x00143011:return VR::DS;
case 0x00143012:return VR::DS;
case 0x00143020:return VR::SQ;
case 0x00143022:return VR::ST;
case 0x00143024:return VR::DS;
case 0x00143026:return VR::DS;
case 0x00143028:return VR::DS;
case 0x00143040:return VR::SQ;
case 0x00143060:return VR::SQ;
case 0x00143071:return VR::DS;
case 0x00143072:return VR::DS;
case 0x00143073:return VR::DS;
case 0x00143074:return VR::LO;
case 0x00143075:return VR::DS;
case 0x00143076:return VR::DA;
case 0x00143077:return VR::TM;
case 0x00143080:return VR::OB;
case 0x00143099:return VR::LT;
case 0x00144002:return VR::SQ;
case 0x00144004:return VR::CS;
case 0x00144006:return VR::LT;
case 0x00144008:return VR::SQ;
case 0x0014400a:return VR::CS;
case 0x0014400c:return VR::LT;
case 0x0014400e:return VR::SQ;
case 0x0014400f:return VR::LT;
case 0x00144010:return VR::SQ;
case 0x00144011:return VR::SQ;
case 0x00144012:return VR::US;
case 0x00144013:return VR::CS;
case 0x00144014:return VR::DS;
case 0x00144015:return VR::DS;
case 0x00144016:return VR::DS;
case 0x00144017:return VR::DS;
case 0x00144018:return VR::DS;
case 0x00144019:return VR::DS;
case 0x0014401a:return VR::DS;
case 0x0014401b:return VR::DS;
case 0x0014401c:return VR::DS;
case 0x00144020:return VR::SQ;
case 0x00144022:return VR::DS;
case 0x00144024:return VR::DS;
case 0x00144026:return VR::CS;
case 0x00144028:return VR::DS;
case 0x00144030:return VR::SQ;
case 0x00144031:return VR::DS;
case 0x00144032:return VR::CS;
case 0x00144033:return VR::IS;
case 0x00144034:return VR::DS;
case 0x00144035:return VR::SQ;
case 0x00144036:return VR::CS;
case 0x00144038:return VR::DS;
case 0x0014403a:return VR::DS;
case 0x0014403c:return VR::DS;
case 0x00144040:return VR::SQ;
case 0x00144050:return VR::SQ;
case 0x00144051:return VR::SQ;
case 0x00144052:return VR::DS;
case 0x00144054:return VR::ST;
case 0x00144056:return VR::ST;
case 0x00144057:return VR::DS;
case 0x00144058:return VR::DS;
case 0x00144059:return VR::DS;
case 0x0014405a:return VR::DS;
case 0x0014405c:return VR::ST;
case 0x00144060:return VR::SQ;
case 0x00144062:return VR::DS;
case 0x00144064:return VR::DS;
case 0x00144070:return VR::SQ;
case 0x00144072:return VR::ST;
case 0x00144074:return VR::SH;
case 0x00144076:return VR::DA;
case 0x00144078:return VR::DA;
case 0x0014407a:return VR::DA;
case 0x0014407c:return VR::TM;
case 0x0014407e:return VR::DA;
case 0x00145002:return VR::IS;
case 0x00145004:return VR::IS;
case 0x00180010:return VR::LO;
case 0x00180012:return VR::SQ;
case 0x00180014:return VR::SQ;
case 0x00180015:return VR::CS;
case 0x00180020:return VR::CS;
case 0x00180021:return VR::CS;
case 0x00180022:return VR::CS;
case 0x00180023:return VR::CS;
case 0x00180024:return VR::SH;
case 0x00180025:return VR::CS;
case 0x00180026:return VR::SQ;
case 0x00180027:return VR::TM;
case 0x00180028:return VR::DS;
case 0x00180029:return VR::SQ;
case 0x0018002a:return VR::SQ;
case 0x00180030:return VR::LO;
case 0x00180031:return VR::LO;
case 0x00180032:return VR::DS;
case 0x00180033:return VR::DS;
case 0x00180034:return VR::LO;
case 0x00180035:return VR::TM;
case 0x00180036:return VR::SQ;
case 0x00180037:return VR::CS;
case 0x00180038:return VR::CS;
case 0x00180039:return VR::CS;
case 0x0018003a:return VR::ST;
case 0x00180040:return VR::IS;
case 0x00180042:return VR::CS;
case 0x00180050:return VR::DS;
case 0x00180060:return VR::DS;
case 0x00180070:return VR::IS;
case 0x00180071:return VR::CS;
case 0x00180072:return VR::DS;
case 0x00180073:return VR::CS;
case 0x00180074:return VR::IS;
case 0x00180075:return VR::IS;
case 0x00180080:return VR::DS;
case 0x00180081:return VR::DS;
case 0x00180082:return VR::DS;
case 0x00180083:return VR::DS;
case 0x00180084:return VR::DS;
case 0x00180085:return VR::SH;
case 0x00180086:return VR::IS;
case 0x00180087:return VR::DS;
case 0x00180088:return VR::DS;
case 0x00180089:return VR::IS;
case 0x00180090:return VR::DS;
case 0x00180091:return VR::IS;
case 0x00180093:return VR::DS;
case 0x00180094:return VR::DS;
case 0x00180095:return VR::DS;
case 0x00181000:return VR::LO;
case 0x00181002:return VR::UI;
case 0x00181003:return VR::LO;
case 0x00181004:return VR::LO;
case 0x00181005:return VR::LO;
case 0x00181006:return VR::LO;
case 0x00181007:return VR::LO;
case 0x00181008:return VR::LO;
case 0x00181010:return VR::LO;
case 0x00181011:return VR::LO;
case 0x00181012:return VR::DA;
case 0x00181014:return VR::TM;
case 0x00181016:return VR::LO;
case 0x00181017:return VR::LO;
case 0x00181018:return VR::LO;
case 0x00181019:return VR::LO;
case 0x0018101a:return VR::LO;
case 0x0018101b:return VR::LO;
case 0x00181020:return VR::LO;
case 0x00181022:return VR::SH;
case 0x00181023:return VR::LO;
case 0x00181030:return VR::LO;
case 0x00181040:return VR::LO;
case 0x00181041:return VR::DS;
case 0x00181042:return VR::TM;
case 0x00181043:return VR::TM;
case 0x00181044:return VR::DS;
case 0x00181045:return VR::IS;
case 0x00181046:return VR::DS;
case 0x00181047:return VR::DS;
case 0x00181048:return VR::CS;
case 0x00181049:return VR::DS;
case 0x00181050:return VR::DS;
case 0x00181060:return VR::DS;
case 0x00181061:return VR::LO;
case 0x00181062:return VR::IS;
case 0x00181063:return VR::DS;
case 0x00181064:return VR::LO;
case 0x00181065:return VR::DS;
case 0x00181066:return VR::DS;
case 0x00181067:return VR::DS;
case 0x00181068:return VR::DS;
case 0x00181069:return VR::DS;
case 0x0018106a:return VR::CS;
case 0x0018106c:return VR::US;
case 0x0018106e:return VR::UL;
case 0x00181070:return VR::LO;
case 0x00181071:return VR::DS;
case 0x00181072:return VR::TM;
case 0x00181073:return VR::TM;
case 0x00181074:return VR::DS;
case 0x00181075:return VR::DS;
case 0x00181076:return VR::DS;
case 0x00181077:return VR::DS;
case 0x00181078:return VR::DT;
case 0x00181079:return VR::DT;
case 0x00181080:return VR::CS;
case 0x00181081:return VR::IS;
case 0x00181082:return VR::IS;
case 0x00181083:return VR::IS;
case 0x00181084:return VR::IS;
case 0x00181085:return VR::LO;
case 0x00181086:return VR::IS;
case 0x00181088:return VR::IS;
case 0x00181090:return VR::IS;
case 0x00181094:return VR::IS;
case 0x00181100:return VR::DS;
case 0x00181110:return VR::DS;
case 0x00181111:return VR::DS;
case 0x00181114:return VR::DS;
case 0x00181120:return VR::DS;
case 0x00181121:return VR::DS;
case 0x00181130:return VR::DS;
case 0x00181131:return VR::DS;
case 0x00181134:return VR::CS;
case 0x00181135:return VR::DS;
case 0x00181136:return VR::DS;
case 0x00181137:return VR::DS;
case 0x00181138:return VR::DS;
case 0x0018113a:return VR::CS;
case 0x00181140:return VR::CS;
case 0x00181141:return VR::DS;
case 0x00181142:return VR::DS;
case 0x00181143:return VR::DS;
case 0x00181144:return VR::DS;
case 0x00181145:return VR::DS;
case 0x00181146:return VR::DS;
case 0x00181147:return VR::CS;
case 0x00181149:return VR::IS;
case 0x00181150:return VR::IS;
case 0x00181151:return VR::IS;
case 0x00181152:return VR::IS;
case 0x00181153:return VR::IS;
case 0x00181154:return VR::DS;
case 0x00181155:return VR::CS;
case 0x00181156:return VR::CS;
case 0x0018115a:return VR::CS;
case 0x0018115e:return VR::DS;
case 0x00181160:return VR::SH;
case 0x00181161:return VR::LO;
case 0x00181162:return VR::DS;
case 0x00181164:return VR::DS;
case 0x00181166:return VR::CS;
case 0x00181170:return VR::IS;
case 0x00181180:return VR::SH;
case 0x00181181:return VR::CS;
case 0x00181182:return VR::IS;
case 0x00181183:return VR::DS;
case 0x00181184:return VR::DS;
case 0x00181190:return VR::DS;
case 0x00181191:return VR::CS;
case 0x001811a0:return VR::DS;
case 0x001811a2:return VR::DS;
case 0x00181200:return VR::DA;
case 0x00181201:return VR::TM;
case 0x00181210:return VR::SH;
case 0x00181240:return VR::IS;
case 0x00181242:return VR::IS;
case 0x00181243:return VR::IS;
case 0x00181244:return VR::US;
case 0x00181250:return VR::SH;
case 0x00181251:return VR::SH;
case 0x00181260:return VR::SH;
case 0x00181261:return VR::LO;
case 0x00181300:return VR::DS;
case 0x00181301:return VR::CS;
case 0x00181302:return VR::IS;
case 0x00181310:return VR::US;
case 0x00181312:return VR::CS;
case 0x00181314:return VR::DS;
case 0x00181315:return VR::CS;
case 0x00181316:return VR::DS;
case 0x00181318:return VR::DS;
case 0x00181400:return VR::LO;
case 0x00181401:return VR::LO;
case 0x00181402:return VR::CS;
case 0x00181403:return VR::CS;
case 0x00181404:return VR::US;
case 0x00181405:return VR::IS;
case 0x00181411:return VR::DS;
case 0x00181412:return VR::DS;
case 0x00181413:return VR::DS;
case 0x00181450:return VR::DS;
case 0x00181460:return VR::DS;
case 0x00181470:return VR::DS;
case 0x00181480:return VR::DS;
case 0x00181490:return VR::CS;
case 0x00181491:return VR::CS;
case 0x00181495:return VR::IS;
case 0x00181500:return VR::CS;
case 0x00181508:return VR::CS;
case 0x00181510:return VR::DS;
case 0x00181511:return VR::DS;
case 0x00181520:return VR::DS;
case 0x00181521:return VR::DS;
case 0x00181530:return VR::DS;
case 0x00181531:return VR::DS;
case 0x00181600:return VR::CS;
case 0x00181602:return VR::IS;
case 0x00181604:return VR::IS;
case 0x00181606:return VR::IS;
case 0x00181608:return VR::IS;
case 0x00181610:return VR::IS;
case 0x00181612:return VR::IS;
case 0x00181620:return VR::IS;
case 0x00181622:return VR::US;
case 0x00181623:return VR::US;
case 0x00181624:return VR::US;
case 0x00181700:return VR::CS;
case 0x00181702:return VR::IS;
case 0x00181704:return VR::IS;
case 0x00181706:return VR::IS;
case 0x00181708:return VR::IS;
case 0x00181710:return VR::IS;
case 0x00181712:return VR::IS;
case 0x00181720:return VR::IS;
case 0x00181800:return VR::CS;
case 0x00181801:return VR::SH;
case 0x00181802:return VR::CS;
case 0x00181803:return VR::LO;
case 0x00182001:return VR::IS;
case 0x00182002:return VR::SH;
case 0x00182003:return VR::DS;
case 0x00182004:return VR::DS;
case 0x00182005:return VR::DS;
case 0x00182006:return VR::SH;
case 0x00182010:return VR::DS;
case 0x00182020:return VR::CS;
case 0x00182030:return VR::DS;
case 0x00183100:return VR::CS;
case 0x00183101:return VR::DS;
case 0x00183102:return VR::DS;
case 0x00183103:return VR::IS;
case 0x00183104:return VR::IS;
case 0x00183105:return VR::IS;
case 0x00184000:return VR::LT;
case 0x00185000:return VR::SH;
case 0x00185010:return VR::LO;
case 0x00185012:return VR::DS;
case 0x00185020:return VR::LO;
case 0x00185021:return VR::LO;
case 0x00185022:return VR::DS;
case 0x00185024:return VR::DS;
case 0x00185026:return VR::DS;
case 0x00185027:return VR::DS;
case 0x00185028:return VR::DS;
case 0x00185029:return VR::DS;
case 0x00185030:return VR::DS;
case 0x00185040:return VR::DS;
case 0x00185050:return VR::IS;
case 0x00185100:return VR::CS;
case 0x00185101:return VR::CS;
case 0x00185104:return VR::SQ;
case 0x00185210:return VR::DS;
case 0x00185212:return VR::DS;
case 0x00186000:return VR::DS;
case 0x00186011:return VR::SQ;
case 0x00186012:return VR::US;
case 0x00186014:return VR::US;
case 0x00186016:return VR::UL;
case 0x00186018:return VR::UL;
case 0x0018601a:return VR::UL;
case 0x0018601c:return VR::UL;
case 0x0018601e:return VR::UL;
case 0x00186020:return VR::SL;
case 0x00186022:return VR::SL;
case 0x00186024:return VR::US;
case 0x00186026:return VR::US;
case 0x00186028:return VR::FD;
case 0x0018602a:return VR::FD;
case 0x0018602c:return VR::FD;
case 0x0018602e:return VR::FD;
case 0x00186030:return VR::UL;
case 0x00186031:return VR::CS;
case 0x00186032:return VR::UL;
case 0x00186034:return VR::FD;
case 0x00186036:return VR::FD;
case 0x00186038:return VR::UL;
case 0x00186039:return VR::SL;
case 0x0018603a:return VR::UL;
case 0x0018603b:return VR::SL;
case 0x0018603c:return VR::UL;
case 0x0018603d:return VR::SL;
case 0x0018603e:return VR::UL;
case 0x0018603f:return VR::SL;
case 0x00186040:return VR::UL;
case 0x00186041:return VR::SL;
case 0x00186042:return VR::UL;
case 0x00186043:return VR::SL;
case 0x00186044:return VR::US;
case 0x00186046:return VR::UL;
case 0x00186048:return VR::UL;
case 0x0018604a:return VR::UL;
case 0x0018604c:return VR::US;
case 0x0018604e:return VR::US;
case 0x00186050:return VR::UL;
case 0x00186052:return VR::UL;
case 0x00186054:return VR::FD;
case 0x00186056:return VR::UL;
case 0x00186058:return VR::UL;
case 0x0018605a:return VR::FL;
case 0x00186060:return VR::FL;
case 0x00187000:return VR::CS;
case 0x00187001:return VR::DS;
case 0x00187004:return VR::CS;
case 0x00187005:return VR::CS;
case 0x00187006:return VR::LT;
case 0x00187008:return VR::LT;
case 0x0018700a:return VR::SH;
case 0x0018700c:return VR::DA;
case 0x0018700e:return VR::TM;
case 0x00187010:return VR::IS;
case 0x00187011:return VR::IS;
case 0x00187012:return VR::DS;
case 0x00187014:return VR::DS;
case 0x00187016:return VR::DS;
case 0x0018701a:return VR::DS;
case 0x00187020:return VR::DS;
case 0x00187022:return VR::DS;
case 0x00187024:return VR::CS;
case 0x00187026:return VR::DS;
case 0x00187028:return VR::DS;
case 0x0018702a:return VR::LO;
case 0x0018702b:return VR::LO;
case 0x00187030:return VR::DS;
case 0x00187032:return VR::DS;
case 0x00187034:return VR::CS;
case 0x00187036:return VR::FL;
case 0x00187038:return VR::FL;
case 0x00187040:return VR::LT;
case 0x00187041:return VR::LT;
case 0x00187042:return VR::DS;
case 0x00187044:return VR::DS;
case 0x00187046:return VR::IS;
case 0x00187048:return VR::DS;
case 0x0018704c:return VR::DS;
case 0x00187050:return VR::CS;
case 0x00187052:return VR::DS;
case 0x00187054:return VR::DS;
case 0x00187056:return VR::FL;
case 0x00187058:return VR::FL;
case 0x00187060:return VR::CS;
case 0x00187062:return VR::LT;
case 0x00187064:return VR::CS;
case 0x00187065:return VR::DS;
case 0x00188150:return VR::DS;
case 0x00188151:return VR::DS;
case 0x00189004:return VR::CS;
case 0x00189005:return VR::SH;
case 0x00189006:return VR::SQ;
case 0x00189008:return VR::CS;
case 0x00189009:return VR::CS;
case 0x00189010:return VR::CS;
case 0x00189011:return VR::CS;
case 0x00189012:return VR::CS;
case 0x00189014:return VR::CS;
case 0x00189015:return VR::CS;
case 0x00189016:return VR::CS;
case 0x00189017:return VR::CS;
case 0x00189018:return VR::CS;
case 0x00189019:return VR::FD;
case 0x00189020:return VR::CS;
case 0x00189021:return VR::CS;
case 0x00189022:return VR::CS;
case 0x00189024:return VR::CS;
case 0x00189025:return VR::CS;
case 0x00189026:return VR::CS;
case 0x00189027:return VR::CS;
case 0x00189028:return VR::CS;
case 0x00189029:return VR::CS;
case 0x00189030:return VR::FD;
case 0x00189032:return VR::CS;
case 0x00189033:return VR::CS;
case 0x00189034:return VR::CS;
case 0x00189035:return VR::FD;
case 0x00189036:return VR::CS;
case 0x00189037:return VR::CS;
case 0x00189041:return VR::LO;
case 0x00189042:return VR::SQ;
case 0x00189043:return VR::CS;
case 0x00189044:return VR::CS;
case 0x00189045:return VR::SQ;
case 0x00189046:return VR::LO;
case 0x00189047:return VR::SH;
case 0x00189048:return VR::CS;
case 0x00189049:return VR::SQ;
case 0x00189050:return VR::LO;
case 0x00189051:return VR::CS;
case 0x00189052:return VR::FD;
case 0x00189053:return VR::FD;
case 0x00189054:return VR::CS;
case 0x00189058:return VR::US;
case 0x00189059:return VR::CS;
case 0x00189060:return VR::CS;
case 0x00189061:return VR::FD;
case 0x00189062:return VR::CS;
case 0x00189063:return VR::FD;
case 0x00189064:return VR::CS;
case 0x00189065:return VR::CS;
case 0x00189066:return VR::US;
case 0x00189067:return VR::CS;
case 0x00189069:return VR::FD;
case 0x00189070:return VR::FD;
case 0x00189073:return VR::FD;
case 0x00189074:return VR::DT;
case 0x00189075:return VR::CS;
case 0x00189076:return VR::SQ;
case 0x00189077:return VR::CS;
case 0x00189078:return VR::CS;
case 0x00189079:return VR::FD;
case 0x00189080:return VR::ST;
case 0x00189081:return VR::CS;
case 0x00189082:return VR::FD;
case 0x00189083:return VR::SQ;
case 0x00189084:return VR::SQ;
case 0x00189085:return VR::CS;
case 0x00189087:return VR::FD;
case 0x00189089:return VR::FD;
case 0x00189090:return VR::FD;
case 0x00189091:return VR::FD;
case 0x00189092:return VR::SQ;
case 0x00189093:return VR::US;
case 0x00189094:return VR::CS;
case 0x00189095:return VR::UL;
case 0x00189096:return VR::FD;
case 0x00189098:return VR::FD;
case 0x00189100:return VR::CS;
case 0x00189101:return VR::CS;
case 0x00189103:return VR::SQ;
case 0x00189104:return VR::FD;
case 0x00189105:return VR::FD;
case 0x00189106:return VR::FD;
case 0x00189107:return VR::SQ;
case 0x00189112:return VR::SQ;
case 0x00189114:return VR::SQ;
case 0x00189115:return VR::SQ;
case 0x00189117:return VR::SQ;
case 0x00189118:return VR::SQ;
case 0x00189119:return VR::SQ;
case 0x00189125:return VR::SQ;
case 0x00189126:return VR::SQ;
case 0x00189127:return VR::UL;
case 0x00189147:return VR::CS;
case 0x00189151:return VR::DT;
case 0x00189152:return VR::SQ;
case 0x00189155:return VR::FD;
case 0x00189159:return VR::UL;
case 0x00189166:return VR::CS;
case 0x00189168:return VR::FD;
case 0x00189169:return VR::CS;
case 0x00189170:return VR::CS;
case 0x00189171:return VR::CS;
case 0x00189172:return VR::CS;
case 0x00189173:return VR::CS;
case 0x00189174:return VR::CS;
case 0x00189175:return VR::LO;
case 0x00189176:return VR::SQ;
case 0x00189177:return VR::CS;
case 0x00189178:return VR::CS;
case 0x00189179:return VR::CS;
case 0x00189180:return VR::CS;
case 0x00189181:return VR::FD;
case 0x00189182:return VR::FD;
case 0x00189183:return VR::CS;
case 0x00189184:return VR::FD;
case 0x00189185:return VR::ST;
case 0x00189186:return VR::SH;
case 0x00189195:return VR::FD;
case 0x00189196:return VR::FD;
case 0x00189197:return VR::SQ;
case 0x00189198:return VR::CS;
case 0x00189199:return VR::CS;
case 0x00189200:return VR::CS;
case 0x00189214:return VR::CS;
case 0x00189217:return VR::FD;
case 0x00189218:return VR::FD;
case 0x00189219:return VR::SS;
case 0x00189220:return VR::FD;
case 0x00189226:return VR::SQ;
case 0x00189227:return VR::SQ;
case 0x00189231:return VR::US;
case 0x00189232:return VR::US;
case 0x00189234:return VR::UL;
case 0x00189236:return VR::CS;
case 0x00189239:return VR::SQ;
case 0x00189240:return VR::US;
case 0x00189241:return VR::US;
case 0x00189250:return VR::CS;
case 0x00189251:return VR::SQ;
case 0x00189252:return VR::LO;
case 0x00189253:return VR::US;
case 0x00189254:return VR::FD;
case 0x00189255:return VR::FD;
case 0x00189256:return VR::FD;
case 0x00189257:return VR::CS;
case 0x00189258:return VR::UL;
case 0x00189259:return VR::CS;
case 0x0018925a:return VR::FD;
case 0x0018925b:return VR::LO;
case 0x0018925c:return VR::CS;
case 0x0018925d:return VR::SQ;
case 0x0018925e:return VR::LO;
case 0x0018925f:return VR::UL;
case 0x00189260:return VR::SQ;
case 0x00189295:return VR::FD;
case 0x00189296:return VR::FD;
case 0x00189301:return VR::SQ;
case 0x00189302:return VR::CS;
case 0x00189303:return VR::FD;
case 0x00189304:return VR::SQ;
case 0x00189305:return VR::FD;
case 0x00189306:return VR::FD;
case 0x00189307:return VR::FD;
case 0x00189308:return VR::SQ;
case 0x00189309:return VR::FD;
case 0x00189310:return VR::FD;
case 0x00189311:return VR::FD;
case 0x00189312:return VR::SQ;
case 0x00189313:return VR::FD;
case 0x00189314:return VR::SQ;
case 0x00189315:return VR::CS;
case 0x00189316:return VR::CS;
case 0x00189317:return VR::FD;
case 0x00189318:return VR::FD;
case 0x00189319:return VR::FD;
case 0x00189320:return VR::SH;
case 0x00189321:return VR::SQ;
case 0x00189322:return VR::FD;
case 0x00189323:return VR::CS;
case 0x00189324:return VR::FD;
case 0x00189325:return VR::SQ;
case 0x00189326:return VR::SQ;
case 0x00189327:return VR::FD;
case 0x00189328:return VR::FD;
case 0x00189329:return VR::SQ;
case 0x00189330:return VR::FD;
case 0x00189332:return VR::FD;
case 0x00189333:return VR::CS;
case 0x00189334:return VR::CS;
case 0x00189335:return VR::FD;
case 0x00189337:return VR::US;
case 0x00189338:return VR::SQ;
case 0x00189340:return VR::SQ;
case 0x00189341:return VR::SQ;
case 0x00189342:return VR::CS;
case 0x00189343:return VR::CS;
case 0x00189344:return VR::CS;
case 0x00189345:return VR::FD;
case 0x00189346:return VR::SQ;
case 0x00189351:return VR::FL;
case 0x00189352:return VR::FL;
case 0x00189353:return VR::FL;
case 0x00189360:return VR::SQ;
case 0x00189401:return VR::SQ;
case 0x00189402:return VR::FL;
case 0x00189403:return VR::FL;
case 0x00189404:return VR::FL;
case 0x00189405:return VR::SQ;
case 0x00189406:return VR::SQ;
case 0x00189407:return VR::SQ;
case 0x00189410:return VR::CS;
case 0x00189412:return VR::SQ;
case 0x00189417:return VR::SQ;
case 0x00189420:return VR::CS;
case 0x00189423:return VR::LO;
case 0x00189424:return VR::LT;
case 0x00189425:return VR::CS;
case 0x00189426:return VR::FL;
case 0x00189427:return VR::CS;
case 0x00189428:return VR::FL;
case 0x00189429:return VR::FL;
case 0x00189430:return VR::FL;
case 0x00189432:return VR::SQ;
case 0x00189433:return VR::LO;
case 0x00189434:return VR::SQ;
case 0x00189435:return VR::CS;
case 0x00189436:return VR::SS;
case 0x00189437:return VR::SS;
case 0x00189438:return VR::SS;
case 0x00189439:return VR::SS;
case 0x00189440:return VR::SS;
case 0x00189441:return VR::US;
case 0x00189442:return VR::SS;
case 0x00189447:return VR::FL;
case 0x00189449:return VR::FL;
case 0x00189451:return VR::SQ;
case 0x00189452:return VR::FL;
case 0x00189455:return VR::SQ;
case 0x00189456:return VR::SQ;
case 0x00189457:return VR::CS;
case 0x00189461:return VR::FL;
case 0x00189462:return VR::SQ;
case 0x00189463:return VR::FL;
case 0x00189464:return VR::FL;
case 0x00189465:return VR::FL;
case 0x00189466:return VR::FL;
case 0x00189467:return VR::FL;
case 0x00189468:return VR::FL;
case 0x00189469:return VR::FL;
case 0x00189470:return VR::FL;
case 0x00189471:return VR::FL;
case 0x00189472:return VR::SQ;
case 0x00189473:return VR::FL;
case 0x00189474:return VR::CS;
case 0x00189476:return VR::SQ;
case 0x00189477:return VR::SQ;
case 0x00189504:return VR::SQ;
case 0x00189506:return VR::SQ;
case 0x00189507:return VR::SQ;
case 0x00189508:return VR::FL;
case 0x00189509:return VR::FL;
case 0x00189510:return VR::FL;
case 0x00189511:return VR::FL;
case 0x00189514:return VR::FL;
case 0x00189515:return VR::FL;
case 0x00189516:return VR::DT;
case 0x00189517:return VR::DT;
case 0x00189524:return VR::LO;
case 0x00189525:return VR::LO;
case 0x00189526:return VR::LO;
case 0x00189527:return VR::CS;
case 0x00189528:return VR::LO;
case 0x00189530:return VR::SQ;
case 0x00189531:return VR::LO;
case 0x00189538:return VR::SQ;
case 0x00189601:return VR::SQ;
case 0x00189602:return VR::FD;
case 0x00189603:return VR::FD;
case 0x00189604:return VR::FD;
case 0x00189605:return VR::FD;
case 0x00189606:return VR::FD;
case 0x00189607:return VR::FD;
case 0x00189701:return VR::DT;
case 0x00189715:return VR::FD;
case 0x00189716:return VR::FD;
case 0x00189717:return VR::FD;
case 0x00189718:return VR::FD;
case 0x00189719:return VR::FD;
case 0x00189720:return VR::FD;
case 0x00189721:return VR::FD;
case 0x00189722:return VR::FD;
case 0x00189723:return VR::FD;
case 0x00189724:return VR::FD;
case 0x00189725:return VR::CS;
case 0x00189726:return VR::FD;
case 0x00189727:return VR::FD;
case 0x00189729:return VR::US;
case 0x00189732:return VR::SQ;
case 0x00189733:return VR::SQ;
case 0x00189734:return VR::SQ;
case 0x00189735:return VR::SQ;
case 0x00189736:return VR::SQ;
case 0x00189737:return VR::SQ;
case 0x00189738:return VR::CS;
case 0x00189739:return VR::US;
case 0x00189740:return VR::US;
case 0x00189749:return VR::SQ;
case 0x00189751:return VR::SQ;
case 0x00189755:return VR::CS;
case 0x00189756:return VR::CS;
case 0x00189758:return VR::CS;
case 0x00189759:return VR::CS;
case 0x00189760:return VR::CS;
case 0x00189761:return VR::CS;
case 0x00189762:return VR::CS;
case 0x00189763:return VR::CS;
case 0x00189764:return VR::CS;
case 0x00189765:return VR::CS;
case 0x00189766:return VR::CS;
case 0x00189767:return VR::CS;
case 0x00189768:return VR::CS;
case 0x00189769:return VR::CS;
case 0x00189770:return VR::CS;
case 0x00189771:return VR::SQ;
case 0x00189772:return VR::SQ;
case 0x00189801:return VR::FD;
case 0x00189803:return VR::SQ;
case 0x00189804:return VR::DT;
case 0x00189805:return VR::FD;
case 0x00189806:return VR::SQ;
case 0x00189807:return VR::SQ;
case 0x00189808:return VR::CS;
case 0x00189809:return VR::SQ;
case 0x0018980b:return VR::CS;
case 0x0018980c:return VR::CS;
case 0x0018980d:return VR::SQ;
case 0x0018980e:return VR::SQ;
case 0x0018980f:return VR::SQ;
case 0x0018a001:return VR::SQ;
case 0x0018a002:return VR::DT;
case 0x0018a003:return VR::ST;
case 0x0020000d:return VR::UI;
case 0x0020000e:return VR::UI;
case 0x00200010:return VR::SH;
case 0x00200011:return VR::IS;
case 0x00200012:return VR::IS;
case 0x00200013:return VR::IS;
case 0x00200014:return VR::IS;
case 0x00200015:return VR::IS;
case 0x00200016:return VR::IS;
case 0x00200017:return VR::IS;
case 0x00200018:return VR::IS;
case 0x00200019:return VR::IS;
case 0x00200020:return VR::CS;
case 0x00200022:return VR::IS;
case 0x00200024:return VR::IS;
case 0x00200026:return VR::IS;
case 0x00200030:return VR::DS;
case 0x00200032:return VR::DS;
case 0x00200035:return VR::DS;
case 0x00200037:return VR::DS;
case 0x00200050:return VR::DS;
case 0x00200052:return VR::UI;
case 0x00200060:return VR::CS;
case 0x00200062:return VR::CS;
case 0x00200070:return VR::LO;
case 0x00200080:return VR::CS;
case 0x002000aa:return VR::IS;
case 0x00200100:return VR::IS;
case 0x00200105:return VR::IS;
case 0x00200110:return VR::DS;
case 0x00200200:return VR::UI;
case 0x00200242:return VR::UI;
case 0x00201000:return VR::IS;
case 0x00201001:return VR::IS;
case 0x00201002:return VR::IS;
case 0x00201003:return VR::IS;
case 0x00201004:return VR::IS;
case 0x00201005:return VR::IS;
case 0x00201020:return VR::LO;
case 0x00201040:return VR::LO;
case 0x00201041:return VR::DS;
case 0x00201070:return VR::IS;
case 0x00201200:return VR::IS;
case 0x00201202:return VR::IS;
case 0x00201204:return VR::IS;
case 0x00201206:return VR::IS;
case 0x00201208:return VR::IS;
case 0x00201209:return VR::IS;
case 0x00203401:return VR::CS;
case 0x00203402:return VR::CS;
case 0x00203403:return VR::DA;
case 0x00203404:return VR::LO;
case 0x00203405:return VR::TM;
case 0x00203406:return VR::LO;
case 0x00204000:return VR::LT;
case 0x00205000:return VR::AT;
case 0x00205002:return VR::LO;
case 0x00209056:return VR::SH;
case 0x00209057:return VR::UL;
case 0x00209071:return VR::SQ;
case 0x00209072:return VR::CS;
case 0x00209111:return VR::SQ;
case 0x00209113:return VR::SQ;
case 0x00209116:return VR::SQ;
case 0x00209128:return VR::UL;
case 0x00209153:return VR::FD;
case 0x00209154:return VR::FL;
case 0x00209155:return VR::FL;
case 0x00209156:return VR::US;
case 0x00209157:return VR::UL;
case 0x00209158:return VR::LT;
case 0x00209161:return VR::UI;
case 0x00209162:return VR::US;
case 0x00209163:return VR::US;
case 0x00209164:return VR::UI;
case 0x00209165:return VR::AT;
case 0x00209167:return VR::AT;
case 0x00209213:return VR::LO;
case 0x00209221:return VR::SQ;
case 0x00209222:return VR::SQ;
case 0x00209228:return VR::UL;
case 0x00209238:return VR::LO;
case 0x00209241:return VR::FL;
case 0x00209245:return VR::FL;
case 0x00209246:return VR::FL;
case 0x00209247:return VR::CS;
case 0x00209248:return VR::FL;
case 0x00209249:return VR::CS;
case 0x00209250:return VR::CS;
case 0x00209251:return VR::FD;
case 0x00209252:return VR::FD;
case 0x00209253:return VR::SQ;
case 0x00209254:return VR::FD;
case 0x00209255:return VR::FD;
case 0x00209256:return VR::FD;
case 0x00209257:return VR::FD;
case 0x00209301:return VR::FD;
case 0x00209302:return VR::FD;
case 0x00209307:return VR::CS;
case 0x00209308:return VR::FD;
case 0x00209309:return VR::FD;
case 0x0020930a:return VR::FD;
case 0x0020930c:return VR::CS;
case 0x0020930d:return VR::FD;
case 0x0020930e:return VR::SQ;
case 0x0020930f:return VR::SQ;
case 0x00209310:return VR::SQ;
case 0x00209311:return VR::CS;
case 0x00209312:return VR::UI;
case 0x00209313:return VR::UI;
case 0x00209421:return VR::LO;
case 0x00209450:return VR::SQ;
case 0x00209453:return VR::LO;
case 0x00209518:return VR::US;
case 0x00209529:return VR::SQ;
case 0x00209536:return VR::US;
case 0x00220001:return VR::US;
case 0x00220002:return VR::US;
case 0x00220003:return VR::US;
case 0x00220004:return VR::US;
case 0x00220005:return VR::CS;
case 0x00220006:return VR::SQ;
case 0x00220007:return VR::FL;
case 0x00220008:return VR::FL;
case 0x00220009:return VR::FL;
case 0x0022000a:return VR::FL;
case 0x0022000b:return VR::FL;
case 0x0022000c:return VR::FL;
case 0x0022000d:return VR::CS;
case 0x0022000e:return VR::FL;
case 0x00220010:return VR::FL;
case 0x00220011:return VR::FL;
case 0x00220012:return VR::FL;
case 0x00220013:return VR::FL;
case 0x00220014:return VR::FL;
case 0x00220015:return VR::SQ;
case 0x00220016:return VR::SQ;
case 0x00220017:return VR::SQ;
case 0x00220018:return VR::SQ;
case 0x00220019:return VR::SQ;
case 0x0022001a:return VR::SQ;
case 0x0022001b:return VR::SQ;
case 0x0022001c:return VR::SQ;
case 0x0022001d:return VR::SQ;
case 0x0022001e:return VR::FL;
case 0x00220020:return VR::SQ;
case 0x00220021:return VR::SQ;
case 0x00220022:return VR::SQ;
case 0x00220030:return VR::FL;
case 0x00220031:return VR::SQ;
case 0x00220032:return VR::FL;
case 0x00220035:return VR::FL;
case 0x00220036:return VR::FL;
case 0x00220037:return VR::FL;
case 0x00220038:return VR::FL;
case 0x00220039:return VR::CS;
case 0x00220041:return VR::FL;
case 0x00220042:return VR::SQ;
case 0x00220048:return VR::FL;
case 0x00220049:return VR::FL;
case 0x0022004e:return VR::DS;
case 0x00220055:return VR::FL;
case 0x00220056:return VR::FL;
case 0x00220057:return VR::FL;
case 0x00220058:return VR::SQ;
case 0x00221007:return VR::SQ;
case 0x00221008:return VR::SQ;
case 0x00221009:return VR::CS;
case 0x00221010:return VR::CS;
case 0x00221012:return VR::SQ;
case 0x00221019:return VR::FL;
case 0x00221024:return VR::SQ;
case 0x00221025:return VR::SQ;
case 0x00221028:return VR::SQ;
case 0x00221029:return VR::LO;
case 0x00221033:return VR::FL;
case 0x00221035:return VR::SQ;
case 0x00221037:return VR::FL;
case 0x00221039:return VR::CS;
case 0x00221040:return VR::SQ;
case 0x00221044:return VR::SQ;
case 0x00221050:return VR::SQ;
case 0x00221053:return VR::FL;
case 0x00221054:return VR::FL;
case 0x00221059:return VR::FL;
case 0x00221065:return VR::LO;
case 0x00221066:return VR::LO;
case 0x00221090:return VR::SQ;
case 0x00221092:return VR::SQ;
case 0x00221093:return VR::LO;
case 0x00221094:return VR::LO;
case 0x00221095:return VR::LO;
case 0x00221096:return VR::SQ;
case 0x00221097:return VR::LO;
case 0x00221100:return VR::SQ;
case 0x00221101:return VR::SQ;
case 0x00221103:return VR::SQ;
case 0x00221121:return VR::FL;
case 0x00221122:return VR::FL;
case 0x00221125:return VR::SQ;
case 0x00221127:return VR::SQ;
case 0x00221128:return VR::SQ;
case 0x00221130:return VR::FL;
case 0x00221131:return VR::FL;
case 0x00221132:return VR::SQ;
case 0x00221133:return VR::SQ;
case 0x00221134:return VR::SQ;
case 0x00221135:return VR::SQ;
case 0x00221140:return VR::CS;
case 0x00221150:return VR::SQ;
case 0x00221153:return VR::SQ;
case 0x00221155:return VR::FL;
case 0x00221159:return VR::LO;
case 0x00221210:return VR::SQ;
case 0x00221211:return VR::SQ;
case 0x00221212:return VR::SQ;
case 0x00221220:return VR::SQ;
case 0x00221225:return VR::SQ;
case 0x00221230:return VR::SQ;
case 0x00221250:return VR::SQ;
case 0x00221255:return VR::SQ;
case 0x00221257:return VR::SQ;
case 0x00221260:return VR::SQ;
case 0x00221262:return VR::SQ;
case 0x00221273:return VR::LO;
case 0x00221300:return VR::SQ;
case 0x00221310:return VR::SQ;
case 0x00221330:return VR::SQ;
case 0x00240010:return VR::FL;
case 0x00240011:return VR::FL;
case 0x00240012:return VR::CS;
case 0x00240016:return VR::SQ;
case 0x00240018:return VR::FL;
case 0x00240020:return VR::FL;
case 0x00240021:return VR::SQ;
case 0x00240024:return VR::SQ;
case 0x00240025:return VR::FL;
case 0x00240028:return VR::FL;
case 0x00240032:return VR::SQ;
case 0x00240033:return VR::SQ;
case 0x00240034:return VR::SQ;
case 0x00240035:return VR::US;
case 0x00240036:return VR::US;
case 0x00240037:return VR::CS;
case 0x00240038:return VR::US;
case 0x00240039:return VR::CS;
case 0x00240040:return VR::CS;
case 0x00240042:return VR::US;
case 0x00240044:return VR::LT;
case 0x00240045:return VR::CS;
case 0x00240046:return VR::FL;
case 0x00240048:return VR::US;
case 0x00240050:return VR::US;
case 0x00240051:return VR::CS;
case 0x00240052:return VR::CS;
case 0x00240053:return VR::CS;
case 0x00240054:return VR::FL;
case 0x00240055:return VR::CS;
case 0x00240056:return VR::US;
case 0x00240057:return VR::CS;
case 0x00240058:return VR::SQ;
case 0x00240059:return VR::CS;
case 0x00240060:return VR::US;
case 0x00240061:return VR::CS;
case 0x00240062:return VR::CS;
case 0x00240063:return VR::CS;
case 0x00240064:return VR::SQ;
case 0x00240065:return VR::SQ;
case 0x00240066:return VR::FL;
case 0x00240067:return VR::SQ;
case 0x00240068:return VR::FL;
case 0x00240069:return VR::LO;
case 0x00240070:return VR::FL;
case 0x00240071:return VR::FL;
case 0x00240072:return VR::CS;
case 0x00240073:return VR::FL;
case 0x00240074:return VR::CS;
case 0x00240075:return VR::FL;
case 0x00240076:return VR::CS;
case 0x00240077:return VR::FL;
case 0x00240078:return VR::CS;
case 0x00240079:return VR::FL;
case 0x00240080:return VR::CS;
case 0x00240081:return VR::FL;
case 0x00240083:return VR::SQ;
case 0x00240085:return VR::SQ;
case 0x00240086:return VR::CS;
case 0x00240087:return VR::FL;
case 0x00240088:return VR::FL;
case 0x00240089:return VR::SQ;
case 0x00240090:return VR::FL;
case 0x00240091:return VR::FL;
case 0x00240092:return VR::FL;
case 0x00240093:return VR::CS;
case 0x00240094:return VR::FL;
case 0x00240095:return VR::CS;
case 0x00240096:return VR::FL;
case 0x00240097:return VR::SQ;
case 0x00240098:return VR::FL;
case 0x00240100:return VR::FL;
case 0x00240102:return VR::CS;
case 0x00240103:return VR::FL;
case 0x00240104:return VR::FL;
case 0x00240105:return VR::FL;
case 0x00240106:return VR::CS;
case 0x00240107:return VR::FL;
case 0x00240108:return VR::FL;
case 0x00240110:return VR::SQ;
case 0x00240112:return VR::SQ;
case 0x00240113:return VR::CS;
case 0x00240114:return VR::SQ;
case 0x00240115:return VR::SQ;
case 0x00240117:return VR::CS;
case 0x00240118:return VR::FL;
case 0x00240120:return VR::CS;
case 0x00240122:return VR::SQ;
case 0x00240124:return VR::CS;
case 0x00240126:return VR::FL;
case 0x00240202:return VR::LO;
case 0x00240306:return VR::LO;
case 0x00240307:return VR::LO;
case 0x00240308:return VR::LO;
case 0x00240309:return VR::LO;
case 0x00240317:return VR::SQ;
case 0x00240320:return VR::SQ;
case 0x00240325:return VR::SQ;
case 0x00240338:return VR::CS;
case 0x00240341:return VR::FL;
case 0x00240344:return VR::SQ;
case 0x00280002:return VR::US;
case 0x00280003:return VR::US;
case 0x00280004:return VR::CS;
case 0x00280005:return VR::US;
case 0x00280006:return VR::US;
case 0x00280008:return VR::IS;
case 0x00280009:return VR::AT;
case 0x0028000a:return VR::AT;
case 0x00280010:return VR::US;
case 0x00280011:return VR::US;
case 0x00280012:return VR::US;
case 0x00280014:return VR::US;
case 0x00280030:return VR::DS;
case 0x00280031:return VR::DS;
case 0x00280032:return VR::DS;
case 0x00280034:return VR::IS;
case 0x00280040:return VR::CS;
case 0x00280050:return VR::LO;
case 0x00280051:return VR::CS;
case 0x0028005f:return VR::LO;
case 0x00280060:return VR::CS;
case 0x00280061:return VR::SH;
case 0x00280062:return VR::LO;
case 0x00280063:return VR::SH;
case 0x00280065:return VR::CS;
case 0x00280066:return VR::AT;
case 0x00280068:return VR::US;
case 0x00280069:return VR::US;
case 0x00280070:return VR::US;
case 0x00280071:return VR::US_SS;
case 0x00280080:return VR::US;
case 0x00280081:return VR::US;
case 0x00280082:return VR::US;
case 0x00280090:return VR::CS;
case 0x00280091:return VR::US;
case 0x00280092:return VR::US;
case 0x00280093:return VR::US;
case 0x00280094:return VR::US;
case 0x00280100:return VR::US;
case 0x00280101:return VR::US;
case 0x00280102:return VR::US;
case 0x00280103:return VR::US;
case 0x00280104:return VR::US_SS;
case 0x00280105:return VR::US_SS;
case 0x00280106:return VR::US_SS;
case 0x00280107:return VR::US_SS;
case 0x00280108:return VR::US_SS;
case 0x00280109:return VR::US_SS;
case 0x00280110:return VR::US_SS;
case 0x00280111:return VR::US_SS;
case 0x00280120:return VR::US_SS;
case 0x00280121:return VR::US_SS;
case 0x00280200:return VR::US;
case 0x00280300:return VR::CS;
case 0x00280301:return VR::CS;
case 0x00280302:return VR::CS;
case 0x00280303:return VR::CS;
case 0x00280304:return VR::UI;
case 0x00280400:return VR::LO;
case 0x00280401:return VR::LO;
case 0x00280402:return VR::US;
case 0x00280403:return VR::LO;
case 0x00280404:return VR::AT;
case 0x00280700:return VR::LO;
case 0x00280701:return VR::CS;
case 0x00280702:return VR::AT;
case 0x00280710:return VR::US;
case 0x00280720:return VR::US;
case 0x00280721:return VR::AT;
case 0x00280722:return VR::US;
case 0x00280730:return VR::US;
case 0x00280740:return VR::US;
case 0x00280a02:return VR::CS;
case 0x00280a04:return VR::LO;
case 0x00281040:return VR::CS;
case 0x00281041:return VR::SS;
case 0x00281050:return VR::DS;
case 0x00281051:return VR::DS;
case 0x00281052:return VR::DS;
case 0x00281053:return VR::DS;
case 0x00281054:return VR::LO;
case 0x00281055:return VR::LO;
case 0x00281056:return VR::CS;
case 0x00281080:return VR::CS;
case 0x00281090:return VR::CS;
case 0x00281100:return VR::US_SS;
case 0x00281101:return VR::US_SS;
case 0x00281102:return VR::US_SS;
case 0x00281103:return VR::US_SS;
case 0x00281104:return VR::US;
case 0x00281111:return VR::US_SS;
case 0x00281112:return VR::US_SS;
case 0x00281113:return VR::US_SS;
case 0x00281199:return VR::UI;
case 0x00281201:return VR::OW;
case 0x00281202:return VR::OW;
case 0x00281203:return VR::OW;
case 0x00281204:return VR::OW;
case 0x00281211:return VR::OW;
case 0x00281212:return VR::OW;
case 0x00281213:return VR::OW;
case 0x00281214:return VR::UI;
case 0x00281221:return VR::OW;
case 0x00281222:return VR::OW;
case 0x00281223:return VR::OW;
case 0x00281300:return VR::CS;
case 0x00281350:return VR::CS;
case 0x00281351:return VR::ST;
case 0x00281352:return VR::SQ;
case 0x0028135a:return VR::CS;
case 0x00281401:return VR::SQ;
case 0x00281402:return VR::CS;
case 0x00281403:return VR::US;
case 0x00281404:return VR::SQ;
case 0x00281405:return VR::CS;
case 0x00281406:return VR::FD;
case 0x00281407:return VR::US;
case 0x00281408:return VR::OW;
case 0x0028140b:return VR::SQ;
case 0x0028140c:return VR::SQ;
case 0x0028140d:return VR::CS;
case 0x0028140e:return VR::CS;
case 0x0028140f:return VR::CS;
case 0x00281410:return VR::CS;
case 0x00282000:return VR::OB;
case 0x00282110:return VR::CS;
case 0x00282112:return VR::DS;
case 0x00282114:return VR::CS;
case 0x00283000:return VR::SQ;
case 0x00283002:return VR::US_SS;
case 0x00283003:return VR::LO;
case 0x00283004:return VR::LO;
case 0x00283010:return VR::SQ;
case 0x00283110:return VR::SQ;
case 0x00284000:return VR::LT;
case 0x00285000:return VR::SQ;
case 0x00286010:return VR::US;
case 0x00286020:return VR::US;
case 0x00286022:return VR::LO;
case 0x00286023:return VR::CS;
case 0x00286030:return VR::US;
case 0x00286040:return VR::US;
case 0x00286100:return VR::SQ;
case 0x00286101:return VR::CS;
case 0x00286102:return VR::US;
case 0x00286110:return VR::US;
case 0x00286112:return VR::US;
case 0x00286114:return VR::FL;
case 0x00286120:return VR::SS;
case 0x00286190:return VR::ST;
case 0x00287fe0:return VR::UT;
case 0x00289001:return VR::UL;
case 0x00289002:return VR::UL;
case 0x00289003:return VR::CS;
case 0x00289099:return VR::US;
case 0x00289108:return VR::CS;
case 0x00289110:return VR::SQ;
case 0x00289132:return VR::SQ;
case 0x00289145:return VR::SQ;
case 0x00289235:return VR::CS;
case 0x00289411:return VR::FL;
case 0x00289415:return VR::SQ;
case 0x00289416:return VR::US;
case 0x00289422:return VR::SQ;
case 0x00289443:return VR::SQ;
case 0x00289444:return VR::CS;
case 0x00289445:return VR::FL;
case 0x00289446:return VR::CS;
case 0x00289454:return VR::CS;
case 0x00289474:return VR::CS;
case 0x00289478:return VR::FL;
case 0x00289501:return VR::SQ;
case 0x00289502:return VR::SQ;
case 0x00289503:return VR::SS;
case 0x00289505:return VR::SQ;
case 0x00289506:return VR::US;
case 0x00289507:return VR::US;
case 0x00289520:return VR::DS;
case 0x00289537:return VR::CS;
case 0x0032000a:return VR::CS;
case 0x0032000c:return VR::CS;
case 0x00320012:return VR::LO;
case 0x00320032:return VR::DA;
case 0x00320033:return VR::TM;
case 0x00320034:return VR::DA;
case 0x00320035:return VR::TM;
case 0x00321000:return VR::DA;
case 0x00321001:return VR::TM;
case 0x00321010:return VR::DA;
case 0x00321011:return VR::TM;
case 0x00321020:return VR::LO;
case 0x00321021:return VR::AE;
case 0x00321030:return VR::LO;
case 0x00321031:return VR::SQ;
case 0x00321032:return VR::PN;
case 0x00321033:return VR::LO;
case 0x00321034:return VR::SQ;
case 0x00321040:return VR::DA;
case 0x00321041:return VR::TM;
case 0x00321050:return VR::DA;
case 0x00321051:return VR::TM;
case 0x00321055:return VR::CS;
case 0x00321060:return VR::LO;
case 0x00321064:return VR::SQ;
case 0x00321070:return VR::LO;
case 0x00324000:return VR::LT;
case 0x00380004:return VR::SQ;
case 0x00380008:return VR::CS;
case 0x00380010:return VR::LO;
case 0x00380011:return VR::LO;
case 0x00380014:return VR::SQ;
case 0x00380016:return VR::LO;
case 0x0038001a:return VR::DA;
case 0x0038001b:return VR::TM;
case 0x0038001c:return VR::DA;
case 0x0038001d:return VR::TM;
case 0x0038001e:return VR::LO;
case 0x00380020:return VR::DA;
case 0x00380021:return VR::TM;
case 0x00380030:return VR::DA;
case 0x00380032:return VR::TM;
case 0x00380040:return VR::LO;
case 0x00380044:return VR::SQ;
case 0x00380050:return VR::LO;
case 0x00380060:return VR::LO;
case 0x00380061:return VR::LO;
case 0x00380062:return VR::LO;
case 0x00380064:return VR::SQ;
case 0x00380100:return VR::SQ;
case 0x00380300:return VR::LO;
case 0x00380400:return VR::LO;
case 0x00380500:return VR::LO;
case 0x00380502:return VR::SQ;
case 0x00384000:return VR::LT;
case 0x003a0004:return VR::CS;
case 0x003a0005:return VR::US;
case 0x003a0010:return VR::UL;
case 0x003a001a:return VR::DS;
case 0x003a0020:return VR::SH;
case 0x003a0200:return VR::SQ;
case 0x003a0202:return VR::IS;
case 0x003a0203:return VR::SH;
case 0x003a0205:return VR::CS;
case 0x003a0208:return VR::SQ;
case 0x003a0209:return VR::SQ;
case 0x003a020a:return VR::SQ;
case 0x003a020c:return VR::LO;
case 0x003a0210:return VR::DS;
case 0x003a0211:return VR::SQ;
case 0x003a0212:return VR::DS;
case 0x003a0213:return VR::DS;
case 0x003a0214:return VR::DS;
case 0x003a0215:return VR::DS;
case 0x003a0218:return VR::DS;
case 0x003a021a:return VR::US;
case 0x003a0220:return VR::DS;
case 0x003a0221:return VR::DS;
case 0x003a0222:return VR::DS;
case 0x003a0223:return VR::DS;
case 0x003a0230:return VR::FL;
case 0x003a0231:return VR::US;
case 0x003a0240:return VR::SQ;
case 0x003a0241:return VR::US;
case 0x003a0242:return VR::SQ;
case 0x003a0244:return VR::US;
case 0x003a0245:return VR::FL;
case 0x003a0246:return VR::CS;
case 0x003a0247:return VR::FL;
case 0x003a0248:return VR::FL;
case 0x003a0300:return VR::SQ;
case 0x003a0301:return VR::IS;
case 0x003a0302:return VR::CS;
case 0x00400001:return VR::AE;
case 0x00400002:return VR::DA;
case 0x00400003:return VR::TM;
case 0x00400004:return VR::DA;
case 0x00400005:return VR::TM;
case 0x00400006:return VR::PN;
case 0x00400007:return VR::LO;
case 0x00400008:return VR::SQ;
case 0x00400009:return VR::SH;
case 0x0040000a:return VR::SQ;
case 0x0040000b:return VR::SQ;
case 0x00400010:return VR::SH;
case 0x00400011:return VR::SH;
case 0x00400012:return VR::LO;
case 0x00400020:return VR::CS;
case 0x00400026:return VR::SQ;
case 0x00400027:return VR::SQ;
case 0x00400031:return VR::UT;
case 0x00400032:return VR::UT;
case 0x00400033:return VR::CS;
case 0x00400035:return VR::CS;
case 0x00400036:return VR::SQ;
case 0x00400039:return VR::SQ;
case 0x0040003a:return VR::SQ;
case 0x00400100:return VR::SQ;
case 0x00400220:return VR::SQ;
case 0x00400241:return VR::AE;
case 0x00400242:return VR::SH;
case 0x00400243:return VR::SH;
case 0x00400244:return VR::DA;
case 0x00400245:return VR::TM;
case 0x00400250:return VR::DA;
case 0x00400251:return VR::TM;
case 0x00400252:return VR::CS;
case 0x00400253:return VR::SH;
case 0x00400254:return VR::LO;
case 0x00400255:return VR::LO;
case 0x00400260:return VR::SQ;
case 0x00400261:return VR::CS;
case 0x00400270:return VR::SQ;
case 0x00400275:return VR::SQ;
case 0x00400280:return VR::ST;
case 0x00400281:return VR::SQ;
case 0x00400293:return VR::SQ;
case 0x00400294:return VR::DS;
case 0x00400295:return VR::SQ;
case 0x00400296:return VR::SQ;
case 0x00400300:return VR::US;
case 0x00400301:return VR::US;
case 0x00400302:return VR::US;
case 0x00400303:return VR::US;
case 0x00400306:return VR::DS;
case 0x00400307:return VR::DS;
case 0x0040030e:return VR::SQ;
case 0x00400310:return VR::ST;
case 0x00400312:return VR::DS;
case 0x00400314:return VR::DS;
case 0x00400316:return VR::DS;
case 0x00400318:return VR::CS;
case 0x00400320:return VR::SQ;
case 0x00400321:return VR::SQ;
case 0x00400324:return VR::SQ;
case 0x00400330:return VR::SQ;
case 0x00400340:return VR::SQ;
case 0x00400400:return VR::LT;
case 0x00400440:return VR::SQ;
case 0x00400441:return VR::SQ;
case 0x00400500:return VR::SQ;
case 0x0040050a:return VR::LO;
case 0x00400512:return VR::LO;
case 0x00400513:return VR::SQ;
case 0x00400515:return VR::SQ;
case 0x00400518:return VR::SQ;
case 0x0040051a:return VR::LO;
case 0x00400520:return VR::SQ;
case 0x00400550:return VR::SQ;
case 0x00400551:return VR::LO;
case 0x00400552:return VR::SQ;
case 0x00400553:return VR::ST;
case 0x00400554:return VR::UI;
case 0x00400555:return VR::SQ;
case 0x00400556:return VR::ST;
case 0x0040059a:return VR::SQ;
case 0x00400560:return VR::SQ;
case 0x00400562:return VR::SQ;
case 0x00400600:return VR::LO;
case 0x00400602:return VR::UT;
case 0x00400610:return VR::SQ;
case 0x00400612:return VR::SQ;
case 0x00400620:return VR::SQ;
case 0x004006fa:return VR::LO;
case 0x0040071a:return VR::SQ;
case 0x0040072a:return VR::DS;
case 0x0040073a:return VR::DS;
case 0x0040074a:return VR::DS;
case 0x004008d8:return VR::SQ;
case 0x004008da:return VR::SQ;
case 0x004008ea:return VR::SQ;
case 0x004009f8:return VR::SQ;
case 0x00401001:return VR::SH;
case 0x00401002:return VR::LO;
case 0x00401003:return VR::SH;
case 0x00401004:return VR::LO;
case 0x00401005:return VR::LO;
case 0x00401006:return VR::SH;
case 0x00401007:return VR::SH;
case 0x00401008:return VR::LO;
case 0x00401009:return VR::SH;
case 0x0040100a:return VR::SQ;
case 0x00401010:return VR::PN;
case 0x00401011:return VR::SQ;
case 0x00401012:return VR::SQ;
case 0x00401060:return VR::LO;
case 0x00401101:return VR::SQ;
case 0x00401102:return VR::ST;
case 0x00401103:return VR::LO;
case 0x00401400:return VR::LT;
case 0x00402001:return VR::LO;
case 0x00402004:return VR::DA;
case 0x00402005:return VR::TM;
case 0x00402006:return VR::SH;
case 0x00402007:return VR::SH;
case 0x00402008:return VR::PN;
case 0x00402009:return VR::SH;
case 0x00402010:return VR::SH;
case 0x00402016:return VR::LO;
case 0x00402017:return VR::LO;
case 0x00402400:return VR::LT;
case 0x00403001:return VR::LO;
case 0x00404001:return VR::CS;
case 0x00404002:return VR::CS;
case 0x00404003:return VR::CS;
case 0x00404004:return VR::SQ;
case 0x00404005:return VR::DT;
case 0x00404006:return VR::CS;
case 0x00404007:return VR::SQ;
case 0x00404009:return VR::SQ;
case 0x00404010:return VR::DT;
case 0x00404011:return VR::DT;
case 0x00404015:return VR::SQ;
case 0x00404016:return VR::SQ;
case 0x00404018:return VR::SQ;
case 0x00404019:return VR::SQ;
case 0x00404020:return VR::CS;
case 0x00404021:return VR::SQ;
case 0x00404022:return VR::SQ;
case 0x00404023:return VR::UI;
case 0x00404025:return VR::SQ;
case 0x00404026:return VR::SQ;
case 0x00404027:return VR::SQ;
case 0x00404028:return VR::SQ;
case 0x00404029:return VR::SQ;
case 0x00404030:return VR::SQ;
case 0x00404031:return VR::SQ;
case 0x00404032:return VR::SQ;
case 0x00404033:return VR::SQ;
case 0x00404034:return VR::SQ;
case 0x00404035:return VR::SQ;
case 0x00404036:return VR::LO;
case 0x00404037:return VR::PN;
case 0x00404040:return VR::CS;
case 0x00404041:return VR::CS;
case 0x00404050:return VR::DT;
case 0x00404051:return VR::DT;
case 0x00404052:return VR::DT;
case 0x00408302:return VR::DS;
case 0x00409094:return VR::SQ;
case 0x00409096:return VR::SQ;
case 0x00409098:return VR::SQ;
case 0x00409210:return VR::SH;
case 0x00409211:return VR::US_SS;
case 0x00409212:return VR::FD;
case 0x00409216:return VR::US_SS;
case 0x00409224:return VR::FD;
case 0x00409225:return VR::FD;
case 0x0040a007:return VR::CS;
case 0x0040a010:return VR::CS;
case 0x0040a020:return VR::SQ;
case 0x0040a021:return VR::UI;
case 0x0040a022:return VR::UI;
case 0x0040a023:return VR::DA;
case 0x0040a024:return VR::TM;
case 0x0040a026:return VR::SQ;
case 0x0040a027:return VR::LO;
case 0x0040a028:return VR::SQ;
case 0x0040a030:return VR::DT;
case 0x0040a032:return VR::DT;
case 0x0040a040:return VR::CS;
case 0x0040a043:return VR::SQ;
case 0x0040a047:return VR::LO;
case 0x0040a050:return VR::CS;
case 0x0040a057:return VR::CS;
case 0x0040a060:return VR::LO;
case 0x0040a066:return VR::SQ;
case 0x0040a067:return VR::PN;
case 0x0040a068:return VR::SQ;
case 0x0040a070:return VR::SQ;
case 0x0040a073:return VR::SQ;
case 0x0040a074:return VR::OB;
case 0x0040a075:return VR::PN;
case 0x0040a076:return VR::SQ;
case 0x0040a078:return VR::SQ;
case 0x0040a07a:return VR::SQ;
case 0x0040a07c:return VR::SQ;
case 0x0040a080:return VR::CS;
case 0x0040a082:return VR::DT;
case 0x0040a084:return VR::CS;
case 0x0040a085:return VR::SQ;
case 0x0040a088:return VR::SQ;
case 0x0040a089:return VR::OB;
case 0x0040a090:return VR::SQ;
case 0x0040a0b0:return VR::US;
case 0x0040a110:return VR::DA;
case 0x0040a112:return VR::TM;
case 0x0040a120:return VR::DT;
case 0x0040a121:return VR::DA;
case 0x0040a122:return VR::TM;
case 0x0040a123:return VR::PN;
case 0x0040a124:return VR::UI;
case 0x0040a125:return VR::CS;
case 0x0040a130:return VR::CS;
case 0x0040a132:return VR::UL;
case 0x0040a136:return VR::US;
case 0x0040a138:return VR::DS;
case 0x0040a13a:return VR::DT;
case 0x0040a160:return VR::UT;
case 0x0040a167:return VR::SQ;
case 0x0040a168:return VR::SQ;
case 0x0040a16a:return VR::ST;
case 0x0040a170:return VR::SQ;
case 0x0040a171:return VR::UI;
case 0x0040a172:return VR::UI;
case 0x0040a173:return VR::CS;
case 0x0040a174:return VR::CS;
case 0x0040a180:return VR::US;
case 0x0040a192:return VR::DA;
case 0x0040a193:return VR::TM;
case 0x0040a194:return VR::CS;
case 0x0040a195:return VR::SQ;
case 0x0040a224:return VR::ST;
case 0x0040a290:return VR::CS;
case 0x0040a296:return VR::SQ;
case 0x0040a297:return VR::ST;
case 0x0040a29a:return VR::SL;
case 0x0040a300:return VR::SQ;
case 0x0040a301:return VR::SQ;
case 0x0040a307:return VR::PN;
case 0x0040a30a:return VR::DS;
case 0x0040a313:return VR::SQ;
case 0x0040a33a:return VR::ST;
case 0x0040a340:return VR::SQ;
case 0x0040a352:return VR::PN;
case 0x0040a353:return VR::ST;
case 0x0040a354:return VR::LO;
case 0x0040a358:return VR::SQ;
case 0x0040a360:return VR::SQ;
case 0x0040a370:return VR::SQ;
case 0x0040a372:return VR::SQ;
case 0x0040a375:return VR::SQ;
case 0x0040a380:return VR::SQ;
case 0x0040a385:return VR::SQ;
case 0x0040a390:return VR::SQ;
case 0x0040a402:return VR::UI;
case 0x0040a403:return VR::CS;
case 0x0040a404:return VR::SQ;
case 0x0040a491:return VR::CS;
case 0x0040a492:return VR::LO;
case 0x0040a493:return VR::CS;
case 0x0040a494:return VR::CS;
case 0x0040a496:return VR::CS;
case 0x0040a504:return VR::SQ;
case 0x0040a525:return VR::SQ;
case 0x0040a600:return VR::CS;
case 0x0040a601:return VR::CS;
case 0x0040a603:return VR::CS;
case 0x0040a730:return VR::SQ;
case 0x0040a731:return VR::SQ;
case 0x0040a732:return VR::SQ;
case 0x0040a744:return VR::SQ;
case 0x0040a992:return VR::ST;
case 0x0040b020:return VR::SQ;
case 0x0040db00:return VR::CS;
case 0x0040db06:return VR::DT;
case 0x0040db07:return VR::DT;
case 0x0040db0b:return VR::CS;
case 0x0040db0c:return VR::UI;
case 0x0040db0d:return VR::UI;
case 0x0040db73:return VR::UL;
case 0x0040e001:return VR::ST;
case 0x0040e004:return VR::DT;
case 0x0040e006:return VR::SQ;
case 0x0040e008:return VR::SQ;
case 0x0040e010:return VR::UT;
case 0x0040e011:return VR::UI;
case 0x0040e020:return VR::CS;
case 0x0040e021:return VR::SQ;
case 0x0040e022:return VR::SQ;
case 0x0040e023:return VR::SQ;
case 0x0040e024:return VR::SQ;
case 0x0040e030:return VR::UI;
case 0x0040e031:return VR::UI;
case 0x00420010:return VR::ST;
case 0x00420011:return VR::OB;
case 0x00420012:return VR::LO;
case 0x00420013:return VR::SQ;
case 0x00420014:return VR::LO;
case 0x00440001:return VR::ST;
case 0x00440002:return VR::CS;
case 0x00440003:return VR::LT;
case 0x00440004:return VR::DT;
case 0x00440007:return VR::SQ;
case 0x00440008:return VR::LO;
case 0x00440009:return VR::LT;
case 0x0044000a:return VR::LO;
case 0x0044000b:return VR::DT;
case 0x00440010:return VR::DT;
case 0x00440011:return VR::LO;
case 0x00440012:return VR::LO;
case 0x00440013:return VR::SQ;
case 0x00440019:return VR::SQ;
case 0x00460012:return VR::LO;
case 0x00460014:return VR::SQ;
case 0x00460015:return VR::SQ;
case 0x00460016:return VR::SQ;
case 0x00460018:return VR::SQ;
case 0x00460028:return VR::SQ;
case 0x00460030:return VR::FD;
case 0x00460032:return VR::CS;
case 0x00460034:return VR::FD;
case 0x00460036:return VR::CS;
case 0x00460038:return VR::CS;
case 0x00460040:return VR::FD;
case 0x00460042:return VR::FD;
case 0x00460044:return VR::FD;
case 0x00460046:return VR::FD;
case 0x00460050:return VR::SQ;
case 0x00460052:return VR::SQ;
case 0x00460060:return VR::FD;
case 0x00460062:return VR::FD;
case 0x00460063:return VR::FD;
case 0x00460064:return VR::FD;
case 0x00460070:return VR::SQ;
case 0x00460071:return VR::SQ;
case 0x00460074:return VR::SQ;
case 0x00460075:return VR::FD;
case 0x00460076:return VR::FD;
case 0x00460077:return VR::FD;
case 0x00460080:return VR::SQ;
case 0x00460092:return VR::CS;
case 0x00460094:return VR::CS;
case 0x00460095:return VR::CS;
case 0x00460097:return VR::SQ;
case 0x00460098:return VR::SQ;
case 0x00460100:return VR::SQ;
case 0x00460101:return VR::SQ;
case 0x00460102:return VR::SQ;
case 0x00460104:return VR::FD;
case 0x00460106:return VR::FD;
case 0x00460121:return VR::SQ;
case 0x00460122:return VR::SQ;
case 0x00460123:return VR::SQ;
case 0x00460124:return VR::SQ;
case 0x00460125:return VR::CS;
case 0x00460135:return VR::SS;
case 0x00460137:return VR::FD;
case 0x00460139:return VR::LO;
case 0x00460145:return VR::SQ;
case 0x00460146:return VR::FD;
case 0x00460147:return VR::FD;
case 0x00480001:return VR::FL;
case 0x00480002:return VR::FL;
case 0x00480003:return VR::FL;
case 0x00480006:return VR::UL;
case 0x00480007:return VR::UL;
case 0x00480008:return VR::SQ;
case 0x00480010:return VR::CS;
case 0x00480011:return VR::CS;
case 0x00480012:return VR::CS;
case 0x00480013:return VR::US;
case 0x00480014:return VR::FL;
case 0x00480015:return VR::US;
case 0x00480100:return VR::SQ;
case 0x00480102:return VR::DS;
case 0x00480105:return VR::SQ;
case 0x00480106:return VR::SH;
case 0x00480107:return VR::ST;
case 0x00480108:return VR::SQ;
case 0x00480110:return VR::SQ;
case 0x00480111:return VR::DS;
case 0x00480112:return VR::DS;
case 0x00480113:return VR::DS;
case 0x00480120:return VR::SQ;
case 0x00480200:return VR::SQ;
case 0x00480201:return VR::US;
case 0x00480202:return VR::US;
case 0x00480207:return VR::SQ;
case 0x0048021a:return VR::SQ;
case 0x0048021e:return VR::SL;
case 0x0048021f:return VR::SL;
case 0x00480301:return VR::CS;
case 0x00500004:return VR::CS;
case 0x00500010:return VR::SQ;
case 0x00500012:return VR::SQ;
case 0x00500013:return VR::FD;
case 0x00500014:return VR::DS;
case 0x00500015:return VR::FD;
case 0x00500016:return VR::DS;
case 0x00500017:return VR::CS;
case 0x00500018:return VR::DS;
case 0x00500019:return VR::DS;
case 0x0050001a:return VR::CS;
case 0x0050001b:return VR::LO;
case 0x0050001c:return VR::FD;
case 0x0050001d:return VR::FD;
case 0x0050001e:return VR::LO;
case 0x00500020:return VR::LO;
case 0x00520001:return VR::FL;
case 0x00520002:return VR::FD;
case 0x00520003:return VR::FD;
case 0x00520004:return VR::FD;
case 0x00520006:return VR::CS;
case 0x00520007:return VR::FD;
case 0x00520008:return VR::FD;
case 0x00520009:return VR::FD;
case 0x00520011:return VR::FD;
case 0x00520012:return VR::US;
case 0x00520013:return VR::FD;
case 0x00520014:return VR::FD;
case 0x00520016:return VR::SQ;
case 0x00520025:return VR::SQ;
case 0x00520026:return VR::CS;
case 0x00520027:return VR::SQ;
case 0x00520028:return VR::FD;
case 0x00520029:return VR::SQ;
case 0x00520030:return VR::SS;
case 0x00520031:return VR::CS;
case 0x00520033:return VR::FD;
case 0x00520034:return VR::FD;
case 0x00520036:return VR::US;
case 0x00520038:return VR::US;
case 0x00520039:return VR::CS;
case 0x0052003a:return VR::CS;
case 0x00540010:return VR::US;
case 0x00540011:return VR::US;
case 0x00540012:return VR::SQ;
case 0x00540013:return VR::SQ;
case 0x00540014:return VR::DS;
case 0x00540015:return VR::DS;
case 0x00540016:return VR::SQ;
case 0x00540017:return VR::IS;
case 0x00540018:return VR::SH;
case 0x00540020:return VR::US;
case 0x00540021:return VR::US;
case 0x00540022:return VR::SQ;
case 0x00540030:return VR::US;
case 0x00540031:return VR::US;
case 0x00540032:return VR::SQ;
case 0x00540033:return VR::US;
case 0x00540036:return VR::IS;
case 0x00540038:return VR::IS;
case 0x00540039:return VR::CS;
case 0x00540050:return VR::US;
case 0x00540051:return VR::US;
case 0x00540052:return VR::SQ;
case 0x00540053:return VR::US;
case 0x00540060:return VR::US;
case 0x00540061:return VR::US;
case 0x00540062:return VR::SQ;
case 0x00540063:return VR::SQ;
case 0x00540070:return VR::US;
case 0x00540071:return VR::US;
case 0x00540072:return VR::SQ;
case 0x00540073:return VR::DS;
case 0x00540080:return VR::US;
case 0x00540081:return VR::US;
case 0x00540090:return VR::US;
case 0x00540100:return VR::US;
case 0x00540101:return VR::US;
case 0x00540200:return VR::DS;
case 0x00540202:return VR::CS;
case 0x00540210:return VR::IS;
case 0x00540211:return VR::US;
case 0x00540220:return VR::SQ;
case 0x00540222:return VR::SQ;
case 0x00540300:return VR::SQ;
case 0x00540302:return VR::SQ;
case 0x00540304:return VR::SQ;
case 0x00540306:return VR::SQ;
case 0x00540308:return VR::US;
case 0x00540400:return VR::SH;
case 0x00540410:return VR::SQ;
case 0x00540412:return VR::SQ;
case 0x00540414:return VR::SQ;
case 0x00540500:return VR::CS;
case 0x00541000:return VR::CS;
case 0x00541001:return VR::CS;
case 0x00541002:return VR::CS;
case 0x00541004:return VR::CS;
case 0x00541006:return VR::CS;
case 0x00541100:return VR::CS;
case 0x00541101:return VR::LO;
case 0x00541102:return VR::CS;
case 0x00541103:return VR::LO;
case 0x00541104:return VR::LO;
case 0x00541105:return VR::LO;
case 0x00541200:return VR::DS;
case 0x00541201:return VR::IS;
case 0x00541202:return VR::IS;
case 0x00541203:return VR::DS;
case 0x00541210:return VR::DS;
case 0x00541220:return VR::CS;
case 0x00541300:return VR::DS;
case 0x00541310:return VR::IS;
case 0x00541311:return VR::IS;
case 0x00541320:return VR::DS;
case 0x00541321:return VR::DS;
case 0x00541322:return VR::DS;
case 0x00541323:return VR::DS;
case 0x00541324:return VR::DS;
case 0x00541330:return VR::US;
case 0x00541400:return VR::CS;
case 0x00541401:return VR::CS;
case 0x00603000:return VR::SQ;
case 0x00603002:return VR::US;
case 0x00603004:return VR::US_SS;
case 0x00603006:return VR::US_SS;
case 0x00603008:return VR::US;
case 0x00603010:return VR::LO;
case 0x00603020:return VR::UL;
case 0x00620001:return VR::CS;
case 0x00620002:return VR::SQ;
case 0x00620003:return VR::SQ;
case 0x00620004:return VR::US;
case 0x00620005:return VR::LO;
case 0x00620006:return VR::ST;
case 0x00620008:return VR::CS;
case 0x00620009:return VR::LO;
case 0x0062000a:return VR::SQ;
case 0x0062000b:return VR::US;
case 0x0062000c:return VR::US;
case 0x0062000d:return VR::US;
case 0x0062000e:return VR::US;
case 0x0062000f:return VR::SQ;
case 0x00620010:return VR::CS;
case 0x00640002:return VR::SQ;
case 0x00640003:return VR::UI;
case 0x00640005:return VR::SQ;
case 0x00640007:return VR::UL;
case 0x00640008:return VR::FD;
case 0x00640009:return VR::OF;
case 0x0064000f:return VR::SQ;
case 0x00640010:return VR::SQ;
case 0x00660001:return VR::UL;
case 0x00660002:return VR::SQ;
case 0x00660003:return VR::UL;
case 0x00660004:return VR::LT;
case 0x00660009:return VR::CS;
case 0x0066000a:return VR::FL;
case 0x0066000b:return VR::LO;
case 0x0066000c:return VR::FL;
case 0x0066000d:return VR::CS;
case 0x0066000e:return VR::CS;
case 0x00660010:return VR::CS;
case 0x00660011:return VR::SQ;
case 0x00660012:return VR::SQ;
case 0x00660013:return VR::SQ;
case 0x00660015:return VR::UL;
case 0x00660016:return VR::OF;
case 0x00660017:return VR::FL;
case 0x00660018:return VR::FL;
case 0x00660019:return VR::FL;
case 0x0066001a:return VR::FL;
case 0x0066001b:return VR::FL;
case 0x0066001c:return VR::FL;
case 0x0066001e:return VR::UL;
case 0x0066001f:return VR::US;
case 0x00660020:return VR::FL;
case 0x00660021:return VR::OF;
case 0x00660023:return VR::OW;
case 0x00660024:return VR::OW;
case 0x00660025:return VR::OW;
case 0x00660026:return VR::SQ;
case 0x00660027:return VR::SQ;
case 0x00660028:return VR::SQ;
case 0x00660029:return VR::OW;
case 0x0066002a:return VR::UL;
case 0x0066002b:return VR::SQ;
case 0x0066002c:return VR::UL;
case 0x0066002d:return VR::SQ;
case 0x0066002e:return VR::SQ;
case 0x0066002f:return VR::SQ;
case 0x00660030:return VR::SQ;
case 0x00660031:return VR::LO;
case 0x00660032:return VR::LT;
case 0x00660034:return VR::SQ;
case 0x00660035:return VR::SQ;
case 0x00660036:return VR::LO;
case 0x00686210:return VR::LO;
case 0x00686221:return VR::LO;
case 0x00686222:return VR::SQ;
case 0x00686223:return VR::CS;
case 0x00686224:return VR::SQ;
case 0x00686225:return VR::SQ;
case 0x00686226:return VR::DT;
case 0x00686230:return VR::SQ;
case 0x00686260:return VR::SQ;
case 0x00686265:return VR::SQ;
case 0x00686270:return VR::DT;
case 0x00686280:return VR::ST;
case 0x006862a0:return VR::SQ;
case 0x006862a5:return VR::FD;
case 0x006862c0:return VR::SQ;
case 0x006862d0:return VR::US;
case 0x006862d5:return VR::LO;
case 0x006862e0:return VR::SQ;
case 0x006862f0:return VR::FD;
case 0x006862f2:return VR::FD;
case 0x00686300:return VR::OB;
case 0x00686310:return VR::US;
case 0x00686320:return VR::SQ;
case 0x00686330:return VR::US;
case 0x00686340:return VR::LO;
case 0x00686345:return VR::ST;
case 0x00686346:return VR::FD;
case 0x00686347:return VR::FD;
case 0x00686350:return VR::US;
case 0x00686360:return VR::SQ;
case 0x00686380:return VR::LO;
case 0x00686390:return VR::FD;
case 0x006863a0:return VR::SQ;
case 0x006863a4:return VR::SQ;
case 0x006863a8:return VR::SQ;
case 0x006863ac:return VR::SQ;
case 0x006863b0:return VR::SQ;
case 0x006863c0:return VR::US;
case 0x006863d0:return VR::LO;
case 0x006863e0:return VR::SQ;
case 0x006863f0:return VR::US;
case 0x00686400:return VR::SQ;
case 0x00686410:return VR::US;
case 0x00686420:return VR::CS;
case 0x00686430:return VR::SQ;
case 0x00686440:return VR::US;
case 0x00686450:return VR::FD;
case 0x00686460:return VR::FD;
case 0x00686470:return VR::SQ;
case 0x00686490:return VR::FD;
case 0x006864a0:return VR::FD;
case 0x006864c0:return VR::FD;
case 0x006864d0:return VR::FD;
case 0x006864f0:return VR::FD;
case 0x00686500:return VR::SQ;
case 0x00686510:return VR::SQ;
case 0x00686520:return VR::SQ;
case 0x00686530:return VR::US;
case 0x00686540:return VR::LO;
case 0x00686545:return VR::SQ;
case 0x00686550:return VR::SQ;
case 0x00686560:return VR::FD;
case 0x00686590:return VR::FD;
case 0x006865a0:return VR::SQ;
case 0x006865b0:return VR::FD;
case 0x006865d0:return VR::FD;
case 0x006865e0:return VR::SQ;
case 0x006865f0:return VR::FD;
case 0x00686610:return VR::FD;
case 0x00686620:return VR::FD;
case 0x00700001:return VR::SQ;
case 0x00700002:return VR::CS;
case 0x00700003:return VR::CS;
case 0x00700004:return VR::CS;
case 0x00700005:return VR::CS;
case 0x00700006:return VR::ST;
case 0x00700008:return VR::SQ;
case 0x00700009:return VR::SQ;
case 0x00700010:return VR::FL;
case 0x00700011:return VR::FL;
case 0x00700012:return VR::CS;
case 0x00700014:return VR::FL;
case 0x00700015:return VR::CS;
case 0x00700020:return VR::US;
case 0x00700021:return VR::US;
case 0x00700022:return VR::FL;
case 0x00700023:return VR::CS;
case 0x00700024:return VR::CS;
case 0x00700040:return VR::IS;
case 0x00700041:return VR::CS;
case 0x00700042:return VR::US;
case 0x00700050:return VR::US;
case 0x00700051:return VR::US;
case 0x00700052:return VR::SL;
case 0x00700053:return VR::SL;
case 0x0070005a:return VR::SQ;
case 0x00700060:return VR::SQ;
case 0x00700062:return VR::IS;
case 0x00700066:return VR::US;
case 0x00700067:return VR::US;
case 0x00700068:return VR::LO;
case 0x00700080:return VR::CS;
case 0x00700081:return VR::LO;
case 0x00700082:return VR::DA;
case 0x00700083:return VR::TM;
case 0x00700084:return VR::PN;
case 0x00700086:return VR::SQ;
case 0x00700087:return VR::SQ;
case 0x00700100:return VR::CS;
case 0x00700101:return VR::DS;
case 0x00700102:return VR::IS;
case 0x00700103:return VR::FL;
case 0x00700207:return VR::LO;
case 0x00700208:return VR::ST;
case 0x00700209:return VR::SQ;
case 0x00700226:return VR::UL;
case 0x00700227:return VR::LO;
case 0x00700228:return VR::CS;
case 0x00700229:return VR::LO;
case 0x00700230:return VR::FD;
case 0x00700231:return VR::SQ;
case 0x00700232:return VR::SQ;
case 0x00700233:return VR::SQ;
case 0x00700234:return VR::SQ;
case 0x00700241:return VR::US;
case 0x00700242:return VR::CS;
case 0x00700243:return VR::CS;
case 0x00700244:return VR::CS;
case 0x00700245:return VR::FL;
case 0x00700246:return VR::FL;
case 0x00700247:return VR::US;
case 0x00700248:return VR::CS;
case 0x00700249:return VR::CS;
case 0x00700250:return VR::CS;
case 0x00700251:return VR::US;
case 0x00700252:return VR::US;
case 0x00700253:return VR::FL;
case 0x00700254:return VR::CS;
case 0x00700255:return VR::UL;
case 0x00700256:return VR::OB;
case 0x00700257:return VR::CS;
case 0x00700258:return VR::FL;
case 0x00700261:return VR::FL;
case 0x00700262:return VR::FL;
case 0x00700273:return VR::FL;
case 0x00700274:return VR::CS;
case 0x00700278:return VR::CS;
case 0x00700279:return VR::CS;
case 0x00700282:return VR::CS;
case 0x00700284:return VR::FL;
case 0x00700285:return VR::FL;
case 0x00700287:return VR::SQ;
case 0x00700288:return VR::FL;
case 0x00700289:return VR::SH;
case 0x00700294:return VR::CS;
case 0x00700295:return VR::UL;
case 0x00700306:return VR::CS;
case 0x00700308:return VR::SQ;
case 0x00700309:return VR::SQ;
case 0x0070030a:return VR::SQ;
case 0x0070030c:return VR::CS;
case 0x0070030d:return VR::SQ;
case 0x0070030f:return VR::ST;
case 0x00700310:return VR::SH;
case 0x00700311:return VR::SQ;
case 0x00700312:return VR::FD;
case 0x00700314:return VR::SQ;
case 0x00700318:return VR::SQ;
case 0x0070031a:return VR::UI;
case 0x0070031c:return VR::SQ;
case 0x0070031e:return VR::SQ;
case 0x00700401:return VR::US;
case 0x00700402:return VR::SQ;
case 0x00700403:return VR::FL;
case 0x00700404:return VR::SQ;
case 0x00700405:return VR::CS;
case 0x00720002:return VR::SH;
case 0x00720004:return VR::LO;
case 0x00720006:return VR::CS;
case 0x00720008:return VR::LO;
case 0x0072000a:return VR::DT;
case 0x0072000c:return VR::SQ;
case 0x0072000e:return VR::SQ;
case 0x00720010:return VR::LO;
case 0x00720012:return VR::SQ;
case 0x00720014:return VR::US;
case 0x00720020:return VR::SQ;
case 0x00720022:return VR::SQ;
case 0x00720024:return VR::CS;
case 0x00720026:return VR::AT;
case 0x00720028:return VR::US;
case 0x00720030:return VR::SQ;
case 0x00720032:return VR::US;
case 0x00720034:return VR::CS;
case 0x00720038:return VR::US;
case 0x0072003a:return VR::CS;
case 0x0072003c:return VR::SS;
case 0x0072003e:return VR::SQ;
case 0x00720040:return VR::LO;
case 0x00720050:return VR::CS;
case 0x00720052:return VR::AT;
case 0x00720054:return VR::LO;
case 0x00720056:return VR::LO;
case 0x00720060:return VR::AT;
case 0x00720062:return VR::CS;
case 0x00720064:return VR::IS;
case 0x00720066:return VR::LO;
case 0x00720068:return VR::LT;
case 0x0072006a:return VR::PN;
case 0x0072006c:return VR::SH;
case 0x0072006e:return VR::ST;
case 0x00720070:return VR::UT;
case 0x00720072:return VR::DS;
case 0x00720074:return VR::FD;
case 0x00720076:return VR::FL;
case 0x00720078:return VR::UL;
case 0x0072007a:return VR::US;
case 0x0072007c:return VR::SL;
case 0x0072007e:return VR::SS;
case 0x00720080:return VR::SQ;
case 0x00720100:return VR::US;
case 0x00720102:return VR::SQ;
case 0x00720104:return VR::US;
case 0x00720106:return VR::US;
case 0x00720108:return VR::FD;
case 0x0072010a:return VR::US;
case 0x0072010c:return VR::US;
case 0x0072010e:return VR::US;
case 0x00720200:return VR::SQ;
case 0x00720202:return VR::US;
case 0x00720203:return VR::LO;
case 0x00720204:return VR::US;
case 0x00720206:return VR::LO;
case 0x00720208:return VR::CS;
case 0x00720210:return VR::SQ;
case 0x00720212:return VR::US;
case 0x00720214:return VR::SQ;
case 0x00720216:return VR::US;
case 0x00720218:return VR::US;
case 0x00720300:return VR::SQ;
case 0x00720302:return VR::US;
case 0x00720304:return VR::CS;
case 0x00720306:return VR::US;
case 0x00720308:return VR::US;
case 0x00720310:return VR::CS;
case 0x00720312:return VR::CS;
case 0x00720314:return VR::US;
case 0x00720316:return VR::CS;
case 0x00720318:return VR::US;
case 0x00720320:return VR::US;
case 0x00720330:return VR::FD;
case 0x00720400:return VR::SQ;
case 0x00720402:return VR::CS;
case 0x00720404:return VR::CS;
case 0x00720406:return VR::CS;
case 0x00720420:return VR::US;
case 0x00720421:return VR::US;
case 0x00720422:return VR::SQ;
case 0x00720424:return VR::SQ;
case 0x00720427:return VR::SQ;
case 0x00720430:return VR::SQ;
case 0x00720432:return VR::US;
case 0x00720434:return VR::CS;
case 0x00720500:return VR::CS;
case 0x00720510:return VR::CS;
case 0x00720512:return VR::FD;
case 0x00720514:return VR::FD;
case 0x00720516:return VR::CS;
case 0x00720520:return VR::CS;
case 0x00720600:return VR::SQ;
case 0x00720602:return VR::CS;
case 0x00720604:return VR::CS;
case 0x00720700:return VR::CS;
case 0x00720702:return VR::CS;
case 0x00720704:return VR::CS;
case 0x00720705:return VR::SQ;
case 0x00720706:return VR::CS;
case 0x00720710:return VR::CS;
case 0x00720712:return VR::CS;
case 0x00720714:return VR::CS;
case 0x00720716:return VR::CS;
case 0x00720717:return VR::CS;
case 0x00720718:return VR::CS;
case 0x00740120:return VR::FD;
case 0x00740121:return VR::FD;
case 0x00741000:return VR::CS;
case 0x00741002:return VR::SQ;
case 0x00741004:return VR::DS;
case 0x00741006:return VR::ST;
case 0x00741008:return VR::SQ;
case 0x0074100a:return VR::ST;
case 0x0074100c:return VR::LO;
case 0x0074100e:return VR::SQ;
case 0x00741020:return VR::SQ;
case 0x00741022:return VR::CS;
case 0x00741024:return VR::IS;
case 0x00741026:return VR::FD;
case 0x00741027:return VR::FD;
case 0x00741028:return VR::FD;
case 0x0074102a:return VR::FD;
case 0x0074102b:return VR::FD;
case 0x0074102c:return VR::FD;
case 0x0074102d:return VR::FD;
case 0x00741030:return VR::SQ;
case 0x00741032:return VR::CS;
case 0x00741034:return VR::CS;
case 0x00741036:return VR::CS;
case 0x00741038:return VR::DS;
case 0x0074103a:return VR::DS;
case 0x00741040:return VR::SQ;
case 0x00741042:return VR::SQ;
case 0x00741044:return VR::SQ;
case 0x00741046:return VR::SQ;
case 0x00741048:return VR::SQ;
case 0x0074104a:return VR::SQ;
case 0x0074104c:return VR::SQ;
case 0x0074104e:return VR::SQ;
case 0x00741050:return VR::SQ;
case 0x00741052:return VR::AT;
case 0x00741054:return VR::UL;
case 0x00741056:return VR::LO;
case 0x00741057:return VR::IS;
case 0x00741200:return VR::CS;
case 0x00741202:return VR::LO;
case 0x00741204:return VR::LO;
case 0x00741210:return VR::SQ;
case 0x00741212:return VR::SQ;
case 0x00741216:return VR::SQ;
case 0x00741220:return VR::SQ;
case 0x00741222:return VR::LO;
case 0x00741224:return VR::SQ;
case 0x00741230:return VR::LO;
case 0x00741234:return VR::AE;
case 0x00741236:return VR::AE;
case 0x00741238:return VR::LT;
case 0x00741242:return VR::CS;
case 0x00741244:return VR::CS;
case 0x00741246:return VR::CS;
case 0x00741324:return VR::UL;
case 0x00741338:return VR::FD;
case 0x0074133a:return VR::FD;
case 0x00760001:return VR::LO;
case 0x00760003:return VR::LO;
case 0x00760006:return VR::LO;
case 0x00760008:return VR::SQ;
case 0x0076000a:return VR::CS;
case 0x0076000c:return VR::SQ;
case 0x0076000e:return VR::SQ;
case 0x00760010:return VR::SQ;
case 0x00760020:return VR::SQ;
case 0x00760030:return VR::LO;
case 0x00760032:return VR::SQ;
case 0x00760034:return VR::CS;
case 0x00760036:return VR::CS;
case 0x00760038:return VR::CS;
case 0x00760040:return VR::SQ;
case 0x00760055:return VR::US;
case 0x00760060:return VR::SQ;
case 0x00760070:return VR::US;
case 0x00760080:return VR::US;
case 0x00760090:return VR::US;
case 0x007600a0:return VR::US;
case 0x007600b0:return VR::US;
case 0x007600c0:return VR::US;
case 0x00780001:return VR::LO;
case 0x00780010:return VR::ST;
case 0x00780020:return VR::LO;
case 0x00780024:return VR::LO;
case 0x00780026:return VR::SQ;
case 0x00780028:return VR::SQ;
case 0x0078002a:return VR::SQ;
case 0x0078002e:return VR::US;
case 0x00780050:return VR::FD;
case 0x00780060:return VR::FD;
case 0x00780070:return VR::SQ;
case 0x00780090:return VR::FD;
case 0x007800a0:return VR::FD;
case 0x007800b0:return VR::SQ;
case 0x007800b2:return VR::LO;
case 0x007800b4:return VR::SQ;
case 0x007800b6:return VR::US;
case 0x007800b8:return VR::US;
case 0x00880130:return VR::SH;
case 0x00880140:return VR::UI;
case 0x00880200:return VR::SQ;
case 0x00880904:return VR::LO;
case 0x00880906:return VR::ST;
case 0x00880910:return VR::LO;
case 0x00880912:return VR::LO;
case 0x01000410:return VR::CS;
case 0x01000420:return VR::DT;
case 0x01000424:return VR::LT;
case 0x01000426:return VR::LO;
case 0x04000005:return VR::US;
case 0x04000010:return VR::UI;
case 0x04000015:return VR::CS;
case 0x04000020:return VR::AT;
case 0x04000100:return VR::UI;
case 0x04000105:return VR::DT;
case 0x04000110:return VR::CS;
case 0x04000115:return VR::OB;
case 0x04000120:return VR::OB;
case 0x04000305:return VR::CS;
case 0x04000310:return VR::OB;
case 0x04000401:return VR::SQ;
case 0x04000402:return VR::SQ;
case 0x04000403:return VR::SQ;
case 0x04000404:return VR::OB;
case 0x04000500:return VR::SQ;
case 0x04000510:return VR::UI;
case 0x04000520:return VR::OB;
case 0x04000550:return VR::SQ;
case 0x04000561:return VR::SQ;
case 0x04000562:return VR::DT;
case 0x04000563:return VR::LO;
case 0x04000564:return VR::LO;
case 0x04000565:return VR::CS;
case 0x20000010:return VR::IS;
case 0x2000001e:return VR::SQ;
case 0x20000020:return VR::CS;
case 0x20000030:return VR::CS;
case 0x20000040:return VR::CS;
case 0x20000050:return VR::LO;
case 0x20000060:return VR::IS;
case 0x20000061:return VR::IS;
case 0x20000062:return VR::CS;
case 0x20000063:return VR::CS;
case 0x20000065:return VR::CS;
case 0x20000067:return VR::CS;
case 0x20000069:return VR::CS;
case 0x2000006a:return VR::CS;
case 0x200000a0:return VR::US;
case 0x200000a1:return VR::US;
case 0x200000a2:return VR::SQ;
case 0x200000a4:return VR::SQ;
case 0x200000a8:return VR::SQ;
case 0x20000500:return VR::SQ;
case 0x20000510:return VR::SQ;
case 0x20100010:return VR::ST;
case 0x20100030:return VR::CS;
case 0x20100040:return VR::CS;
case 0x20100050:return VR::CS;
case 0x20100052:return VR::CS;
case 0x20100054:return VR::CS;
case 0x20100060:return VR::CS;
case 0x20100080:return VR::CS;
case 0x201000a6:return VR::CS;
case 0x201000a7:return VR::CS;
case 0x201000a8:return VR::CS;
case 0x201000a9:return VR::CS;
case 0x20100100:return VR::CS;
case 0x20100110:return VR::CS;
case 0x20100120:return VR::US;
case 0x20100130:return VR::US;
case 0x20100140:return VR::CS;
case 0x20100150:return VR::ST;
case 0x20100152:return VR::LT;
case 0x20100154:return VR::IS;
case 0x2010015e:return VR::US;
case 0x20100160:return VR::US;
case 0x20100376:return VR::DS;
case 0x20100500:return VR::SQ;
case 0x20100510:return VR::SQ;
case 0x20100520:return VR::SQ;
case 0x20200010:return VR::US;
case 0x20200020:return VR::CS;
case 0x20200030:return VR::DS;
case 0x20200040:return VR::CS;
case 0x20200050:return VR::CS;
case 0x202000a0:return VR::CS;
case 0x202000a2:return VR::CS;
case 0x20200110:return VR::SQ;
case 0x20200111:return VR::SQ;
case 0x20200130:return VR::SQ;
case 0x20200140:return VR::SQ;
case 0x20300010:return VR::US;
case 0x20300020:return VR::LO;
case 0x20400010:return VR::SQ;
case 0x20400011:return VR::US;
case 0x20400020:return VR::SQ;
case 0x20400060:return VR::CS;
case 0x20400070:return VR::CS;
case 0x20400072:return VR::CS;
case 0x20400074:return VR::US;
case 0x20400080:return VR::CS;
case 0x20400082:return VR::CS;
case 0x20400090:return VR::CS;
case 0x20400100:return VR::CS;
case 0x20400500:return VR::SQ;
case 0x20500010:return VR::SQ;
case 0x20500020:return VR::CS;
case 0x20500500:return VR::SQ;
case 0x21000010:return VR::SH;
case 0x21000020:return VR::CS;
case 0x21000030:return VR::CS;
case 0x21000040:return VR::DA;
case 0x21000050:return VR::TM;
case 0x21000070:return VR::AE;
case 0x21000140:return VR::AE;
case 0x21000160:return VR::SH;
case 0x21000170:return VR::IS;
case 0x21000500:return VR::SQ;
case 0x21100010:return VR::CS;
case 0x21100020:return VR::CS;
case 0x21100030:return VR::LO;
case 0x21100099:return VR::SH;
case 0x21200010:return VR::CS;
case 0x21200050:return VR::SQ;
case 0x21200070:return VR::SQ;
case 0x21300010:return VR::SQ;
case 0x21300015:return VR::SQ;
case 0x21300030:return VR::SQ;
case 0x21300040:return VR::SQ;
case 0x21300050:return VR::SQ;
case 0x21300060:return VR::SQ;
case 0x21300080:return VR::SQ;
case 0x213000a0:return VR::SQ;
case 0x213000c0:return VR::SQ;
case 0x22000001:return VR::CS;
case 0x22000002:return VR::UT;
case 0x22000003:return VR::CS;
case 0x22000004:return VR::LT;
case 0x22000005:return VR::LT;
case 0x22000006:return VR::CS;
case 0x22000007:return VR::CS;
case 0x22000008:return VR::CS;
case 0x22000009:return VR::CS;
case 0x2200000a:return VR::CS;
case 0x2200000b:return VR::US;
case 0x2200000c:return VR::LO;
case 0x2200000d:return VR::SQ;
case 0x2200000e:return VR::AT;
case 0x2200000f:return VR::CS;
case 0x22000020:return VR::CS;
case 0x30020002:return VR::SH;
case 0x30020003:return VR::LO;
case 0x30020004:return VR::ST;
case 0x3002000a:return VR::CS;
case 0x3002000c:return VR::CS;
case 0x3002000d:return VR::DS;
case 0x3002000e:return VR::DS;
case 0x30020010:return VR::DS;
case 0x30020011:return VR::DS;
case 0x30020012:return VR::DS;
case 0x30020020:return VR::SH;
case 0x30020022:return VR::DS;
case 0x30020024:return VR::DS;
case 0x30020026:return VR::DS;
case 0x30020028:return VR::DS;
case 0x30020029:return VR::IS;
case 0x30020030:return VR::SQ;
case 0x30020032:return VR::DS;
case 0x30020034:return VR::DS;
case 0x30020040:return VR::SQ;
case 0x30020041:return VR::CS;
case 0x30020042:return VR::DS;
case 0x30020050:return VR::SQ;
case 0x30020051:return VR::CS;
case 0x30020052:return VR::SH;
case 0x30040001:return VR::CS;
case 0x30040002:return VR::CS;
case 0x30040004:return VR::CS;
case 0x30040006:return VR::LO;
case 0x30040008:return VR::DS;
case 0x3004000a:return VR::CS;
case 0x3004000c:return VR::DS;
case 0x3004000e:return VR::DS;
case 0x30040010:return VR::SQ;
case 0x30040012:return VR::DS;
case 0x30040014:return VR::CS;
case 0x30040040:return VR::DS;
case 0x30040042:return VR::DS;
case 0x30040050:return VR::SQ;
case 0x30040052:return VR::DS;
case 0x30040054:return VR::CS;
case 0x30040056:return VR::IS;
case 0x30040058:return VR::DS;
case 0x30040060:return VR::SQ;
case 0x30040062:return VR::CS;
case 0x30040070:return VR::DS;
case 0x30040072:return VR::DS;
case 0x30040074:return VR::DS;
case 0x30060002:return VR::SH;
case 0x30060004:return VR::LO;
case 0x30060006:return VR::ST;
case 0x30060008:return VR::DA;
case 0x30060009:return VR::TM;
case 0x30060010:return VR::SQ;
case 0x30060012:return VR::SQ;
case 0x30060014:return VR::SQ;
case 0x30060016:return VR::SQ;
case 0x30060020:return VR::SQ;
case 0x30060022:return VR::IS;
case 0x30060024:return VR::UI;
case 0x30060026:return VR::LO;
case 0x30060028:return VR::ST;
case 0x3006002a:return VR::IS;
case 0x3006002c:return VR::DS;
case 0x30060030:return VR::SQ;
case 0x30060033:return VR::CS;
case 0x30060036:return VR::CS;
case 0x30060038:return VR::LO;
case 0x30060039:return VR::SQ;
case 0x30060040:return VR::SQ;
case 0x30060042:return VR::CS;
case 0x30060044:return VR::DS;
case 0x30060045:return VR::DS;
case 0x30060046:return VR::IS;
case 0x30060048:return VR::IS;
case 0x30060049:return VR::IS;
case 0x30060050:return VR::DS;
case 0x30060080:return VR::SQ;
case 0x30060082:return VR::IS;
case 0x30060084:return VR::IS;
case 0x30060085:return VR::SH;
case 0x30060086:return VR::SQ;
case 0x30060088:return VR::ST;
case 0x300600a0:return VR::SQ;
case 0x300600a4:return VR::CS;
case 0x300600a6:return VR::PN;
case 0x300600b0:return VR::SQ;
case 0x300600b2:return VR::CS;
case 0x300600b4:return VR::DS;
case 0x300600b6:return VR::SQ;
case 0x300600b7:return VR::US;
case 0x300600b8:return VR::FL;
case 0x300600c0:return VR::SQ;
case 0x300600c2:return VR::UI;
case 0x300600c4:return VR::CS;
case 0x300600c6:return VR::DS;
case 0x300600c8:return VR::LO;
case 0x30080010:return VR::SQ;
case 0x30080012:return VR::ST;
case 0x30080014:return VR::CS;
case 0x30080016:return VR::DS;
case 0x30080020:return VR::SQ;
case 0x30080021:return VR::SQ;
case 0x30080022:return VR::IS;
case 0x30080024:return VR::DA;
case 0x30080025:return VR::TM;
case 0x3008002a:return VR::CS;
case 0x3008002b:return VR::SH;
case 0x3008002c:return VR::CS;
case 0x30080030:return VR::SQ;
case 0x30080032:return VR::DS;
case 0x30080033:return VR::DS;
case 0x30080036:return VR::DS;
case 0x30080037:return VR::DS;
case 0x3008003a:return VR::DS;
case 0x3008003b:return VR::DS;
case 0x30080040:return VR::SQ;
case 0x30080041:return VR::SQ;
case 0x30080042:return VR::DS;
case 0x30080044:return VR::DS;
case 0x30080045:return VR::FL;
case 0x30080046:return VR::FL;
case 0x30080047:return VR::FL;
case 0x30080048:return VR::DS;
case 0x30080050:return VR::SQ;
case 0x30080052:return VR::DS;
case 0x30080054:return VR::DA;
case 0x30080056:return VR::DA;
case 0x3008005a:return VR::IS;
case 0x30080060:return VR::SQ;
case 0x30080061:return VR::AT;
case 0x30080062:return VR::AT;
case 0x30080063:return VR::IS;
case 0x30080064:return VR::IS;
case 0x30080065:return VR::AT;
case 0x30080066:return VR::ST;
case 0x30080068:return VR::SQ;
case 0x3008006a:return VR::FL;
case 0x30080070:return VR::SQ;
case 0x30080072:return VR::IS;
case 0x30080074:return VR::ST;
case 0x30080076:return VR::DS;
case 0x30080078:return VR::DS;
case 0x3008007a:return VR::DS;
case 0x30080080:return VR::SQ;
case 0x30080082:return VR::IS;
case 0x30080090:return VR::SQ;
case 0x30080092:return VR::IS;
case 0x300800a0:return VR::SQ;
case 0x300800b0:return VR::SQ;
case 0x300800c0:return VR::SQ;
case 0x300800d0:return VR::SQ;
case 0x300800e0:return VR::SQ;
case 0x300800f0:return VR::SQ;
case 0x300800f2:return VR::SQ;
case 0x300800f4:return VR::SQ;
case 0x300800f6:return VR::SQ;
case 0x30080100:return VR::SQ;
case 0x30080105:return VR::LO;
case 0x30080110:return VR::SQ;
case 0x30080116:return VR::CS;
case 0x30080120:return VR::SQ;
case 0x30080122:return VR::IS;
case 0x30080130:return VR::SQ;
case 0x30080132:return VR::DS;
case 0x30080134:return VR::DS;
case 0x30080136:return VR::IS;
case 0x30080138:return VR::IS;
case 0x3008013a:return VR::DS;
case 0x3008013c:return VR::DS;
case 0x30080140:return VR::SQ;
case 0x30080142:return VR::IS;
case 0x30080150:return VR::SQ;
case 0x30080152:return VR::IS;
case 0x30080160:return VR::SQ;
case 0x30080162:return VR::DA;
case 0x30080164:return VR::TM;
case 0x30080166:return VR::DA;
case 0x30080168:return VR::TM;
case 0x30080200:return VR::CS;
case 0x30080202:return VR::ST;
case 0x30080220:return VR::SQ;
case 0x30080223:return VR::IS;
case 0x30080224:return VR::CS;
case 0x30080230:return VR::CS;
case 0x30080240:return VR::SQ;
case 0x30080250:return VR::DA;
case 0x30080251:return VR::TM;
case 0x300a0002:return VR::SH;
case 0x300a0003:return VR::LO;
case 0x300a0004:return VR::ST;
case 0x300a0006:return VR::DA;
case 0x300a0007:return VR::TM;
case 0x300a0009:return VR::LO;
case 0x300a000a:return VR::CS;
case 0x300a000b:return VR::LO;
case 0x300a000c:return VR::CS;
case 0x300a000e:return VR::ST;
case 0x300a0010:return VR::SQ;
case 0x300a0012:return VR::IS;
case 0x300a0013:return VR::UI;
case 0x300a0014:return VR::CS;
case 0x300a0015:return VR::CS;
case 0x300a0016:return VR::LO;
case 0x300a0018:return VR::DS;
case 0x300a001a:return VR::DS;
case 0x300a0020:return VR::CS;
case 0x300a0021:return VR::DS;
case 0x300a0022:return VR::DS;
case 0x300a0023:return VR::DS;
case 0x300a0025:return VR::DS;
case 0x300a0026:return VR::DS;
case 0x300a0027:return VR::DS;
case 0x300a0028:return VR::DS;
case 0x300a002a:return VR::DS;
case 0x300a002b:return VR::DS;
case 0x300a002c:return VR::DS;
case 0x300a002d:return VR::DS;
case 0x300a0040:return VR::SQ;
case 0x300a0042:return VR::IS;
case 0x300a0043:return VR::SH;
case 0x300a0044:return VR::DS;
case 0x300a0046:return VR::DS;
case 0x300a0048:return VR::SQ;
case 0x300a004a:return VR::DS;
case 0x300a004b:return VR::FL;
case 0x300a004c:return VR::DS;
case 0x300a004e:return VR::DS;
case 0x300a004f:return VR::FL;
case 0x300a0050:return VR::FL;
case 0x300a0051:return VR::DS;
case 0x300a0052:return VR::DS;
case 0x300a0053:return VR::DS;
case 0x300a0055:return VR::CS;
case 0x300a0070:return VR::SQ;
case 0x300a0071:return VR::IS;
case 0x300a0072:return VR::LO;
case 0x300a0078:return VR::IS;
case 0x300a0079:return VR::IS;
case 0x300a007a:return VR::IS;
case 0x300a007b:return VR::LT;
case 0x300a0080:return VR::IS;
case 0x300a0082:return VR::DS;
case 0x300a0084:return VR::DS;
case 0x300a0086:return VR::DS;
case 0x300a0088:return VR::FL;
case 0x300a0089:return VR::FL;
case 0x300a008a:return VR::FL;
case 0x300a00a0:return VR::IS;
case 0x300a00a2:return VR::DS;
case 0x300a00a4:return VR::DS;
case 0x300a00b0:return VR::SQ;
case 0x300a00b2:return VR::SH;
case 0x300a00b3:return VR::CS;
case 0x300a00b4:return VR::DS;
case 0x300a00b6:return VR::SQ;
case 0x300a00b8:return VR::CS;
case 0x300a00ba:return VR::DS;
case 0x300a00bb:return VR::FL;
case 0x300a00bc:return VR::IS;
case 0x300a00be:return VR::DS;
case 0x300a00c0:return VR::IS;
case 0x300a00c2:return VR::LO;
case 0x300a00c3:return VR::ST;
case 0x300a00c4:return VR::CS;
case 0x300a00c6:return VR::CS;
case 0x300a00c7:return VR::CS;
case 0x300a00c8:return VR::IS;
case 0x300a00ca:return VR::SQ;
case 0x300a00cc:return VR::LO;
case 0x300a00ce:return VR::CS;
case 0x300a00d0:return VR::IS;
case 0x300a00d1:return VR::SQ;
case 0x300a00d2:return VR::IS;
case 0x300a00d3:return VR::CS;
case 0x300a00d4:return VR::SH;
case 0x300a00d5:return VR::IS;
case 0x300a00d6:return VR::DS;
case 0x300a00d7:return VR::FL;
case 0x300a00d8:return VR::DS;
case 0x300a00d9:return VR::FL;
case 0x300a00da:return VR::DS;
case 0x300a00db:return VR::FL;
case 0x300a00dc:return VR::SH;
case 0x300a00dd:return VR::ST;
case 0x300a00e0:return VR::IS;
case 0x300a00e1:return VR::SH;
case 0x300a00e2:return VR::DS;
case 0x300a00e3:return VR::SQ;
case 0x300a00e4:return VR::IS;
case 0x300a00e5:return VR::SH;
case 0x300a00e6:return VR::DS;
case 0x300a00e7:return VR::IS;
case 0x300a00e8:return VR::IS;
case 0x300a00e9:return VR::DS;
case 0x300a00ea:return VR::DS;
case 0x300a00eb:return VR::DS;
case 0x300a00ec:return VR::DS;
case 0x300a00ed:return VR::IS;
case 0x300a00ee:return VR::CS;
case 0x300a00f0:return VR::IS;
case 0x300a00f2:return VR::DS;
case 0x300a00f3:return VR::FL;
case 0x300a00f4:return VR::SQ;
case 0x300a00f5:return VR::SH;
case 0x300a00f6:return VR::DS;
case 0x300a00f7:return VR::FL;
case 0x300a00f8:return VR::CS;
case 0x300a00f9:return VR::LO;
case 0x300a00fa:return VR::CS;
case 0x300a00fb:return VR::CS;
case 0x300a00fc:return VR::IS;
case 0x300a00fe:return VR::LO;
case 0x300a0100:return VR::DS;
case 0x300a0102:return VR::DS;
case 0x300a0104:return VR::IS;
case 0x300a0106:return VR::DS;
case 0x300a0107:return VR::SQ;
case 0x300a0108:return VR::SH;
case 0x300a0109:return VR::CS;
case 0x300a010a:return VR::LO;
case 0x300a010c:return VR::DS;
case 0x300a010e:return VR::DS;
case 0x300a0110:return VR::IS;
case 0x300a0111:return VR::SQ;
case 0x300a0112:return VR::IS;
case 0x300a0114:return VR::DS;
case 0x300a0115:return VR::DS;
case 0x300a0116:return VR::SQ;
case 0x300a0118:return VR::CS;
case 0x300a011a:return VR::SQ;
case 0x300a011c:return VR::DS;
case 0x300a011e:return VR::DS;
case 0x300a011f:return VR::CS;
case 0x300a0120:return VR::DS;
case 0x300a0121:return VR::CS;
case 0x300a0122:return VR::DS;
case 0x300a0123:return VR::CS;
case 0x300a0124:return VR::DS;
case 0x300a0125:return VR::DS;
case 0x300a0126:return VR::CS;
case 0x300a0128:return VR::DS;
case 0x300a0129:return VR::DS;
case 0x300a012a:return VR::DS;
case 0x300a012c:return VR::DS;
case 0x300a012e:return VR::DS;
case 0x300a0130:return VR::DS;
case 0x300a0134:return VR::DS;
case 0x300a0140:return VR::FL;
case 0x300a0142:return VR::CS;
case 0x300a0144:return VR::FL;
case 0x300a0146:return VR::CS;
case 0x300a0148:return VR::FL;
case 0x300a014a:return VR::FL;
case 0x300a014c:return VR::CS;
case 0x300a014e:return VR::FL;
case 0x300a0180:return VR::SQ;
case 0x300a0182:return VR::IS;
case 0x300a0183:return VR::LO;
case 0x300a0184:return VR::LO;
case 0x300a0190:return VR::SQ;
case 0x300a0192:return VR::CS;
case 0x300a0194:return VR::SH;
case 0x300a0196:return VR::ST;
case 0x300a0198:return VR::SH;
case 0x300a0199:return VR::FL;
case 0x300a019a:return VR::FL;
case 0x300a01a0:return VR::SQ;
case 0x300a01a2:return VR::CS;
case 0x300a01a4:return VR::SH;
case 0x300a01a6:return VR::ST;
case 0x300a01a8:return VR::SH;
case 0x300a01b0:return VR::CS;
case 0x300a01b2:return VR::ST;
case 0x300a01b4:return VR::SQ;
case 0x300a01b6:return VR::CS;
case 0x300a01b8:return VR::SH;
case 0x300a01ba:return VR::ST;
case 0x300a01bc:return VR::DS;
case 0x300a01d0:return VR::ST;
case 0x300a01d2:return VR::DS;
case 0x300a01d4:return VR::DS;
case 0x300a01d6:return VR::DS;
case 0x300a0200:return VR::CS;
case 0x300a0202:return VR::CS;
case 0x300a0206:return VR::SQ;
case 0x300a0210:return VR::SQ;
case 0x300a0212:return VR::IS;
case 0x300a0214:return VR::CS;
case 0x300a0216:return VR::LO;
case 0x300a0218:return VR::DS;
case 0x300a021a:return VR::DS;
case 0x300a0222:return VR::DS;
case 0x300a0224:return VR::DS;
case 0x300a0226:return VR::LO;
case 0x300a0228:return VR::DS;
case 0x300a0229:return VR::CS;
case 0x300a022a:return VR::DS;
case 0x300a022b:return VR::DS;
case 0x300a022c:return VR::DA;
case 0x300a022e:return VR::TM;
case 0x300a0230:return VR::SQ;
case 0x300a0232:return VR::CS;
case 0x300a0234:return VR::IS;
case 0x300a0236:return VR::LO;
case 0x300a0238:return VR::LO;
case 0x300a0240:return VR::IS;
case 0x300a0242:return VR::SH;
case 0x300a0244:return VR::LO;
case 0x300a0250:return VR::DS;
case 0x300a0260:return VR::SQ;
case 0x300a0262:return VR::IS;
case 0x300a0263:return VR::SH;
case 0x300a0264:return VR::CS;
case 0x300a0266:return VR::LO;
case 0x300a026a:return VR::DS;
case 0x300a026c:return VR::DS;
case 0x300a0280:return VR::SQ;
case 0x300a0282:return VR::IS;
case 0x300a0284:return VR::DS;
case 0x300a0286:return VR::DS;
case 0x300a0288:return VR::CS;
case 0x300a028a:return VR::IS;
case 0x300a028c:return VR::DS;
case 0x300a0290:return VR::IS;
case 0x300a0291:return VR::SH;
case 0x300a0292:return VR::CS;
case 0x300a0294:return VR::LO;
case 0x300a0296:return VR::DS;
case 0x300a0298:return VR::LO;
case 0x300a029c:return VR::DS;
case 0x300a029e:return VR::DS;
case 0x300a02a0:return VR::DS;
case 0x300a02a2:return VR::IS;
case 0x300a02a4:return VR::DS;
case 0x300a02b0:return VR::SQ;
case 0x300a02b2:return VR::IS;
case 0x300a02b3:return VR::SH;
case 0x300a02b4:return VR::LO;
case 0x300a02b8:return VR::DS;
case 0x300a02ba:return VR::DS;
case 0x300a02c8:return VR::DS;
case 0x300a02d0:return VR::SQ;
case 0x300a02d2:return VR::DS;
case 0x300a02d4:return VR::DS;
case 0x300a02d6:return VR::DS;
case 0x300a02e0:return VR::CS;
case 0x300a02e1:return VR::CS;
case 0x300a02e2:return VR::DS;
case 0x300a02e3:return VR::FL;
case 0x300a02e4:return VR::FL;
case 0x300a02e5:return VR::FL;
case 0x300a02e6:return VR::FL;
case 0x300a02e7:return VR::FL;
case 0x300a02e8:return VR::FL;
case 0x300a02ea:return VR::SQ;
case 0x300a02eb:return VR::LT;
case 0x300a0302:return VR::IS;
case 0x300a0304:return VR::IS;
case 0x300a0306:return VR::SS;
case 0x300a0308:return VR::CS;
case 0x300a030a:return VR::FL;
case 0x300a030c:return VR::SQ;
case 0x300a030d:return VR::FL;
case 0x300a030f:return VR::SH;
case 0x300a0312:return VR::IS;
case 0x300a0314:return VR::SQ;
case 0x300a0316:return VR::IS;
case 0x300a0318:return VR::SH;
case 0x300a0320:return VR::CS;
case 0x300a0322:return VR::LO;
case 0x300a0330:return VR::IS;
case 0x300a0332:return VR::SQ;
case 0x300a0334:return VR::IS;
case 0x300a0336:return VR::SH;
case 0x300a0338:return VR::CS;
case 0x300a033a:return VR::LO;
case 0x300a033c:return VR::FL;
case 0x300a0340:return VR::IS;
case 0x300a0342:return VR::SQ;
case 0x300a0344:return VR::IS;
case 0x300a0346:return VR::SH;
case 0x300a0348:return VR::CS;
case 0x300a034a:return VR::LO;
case 0x300a034c:return VR::SH;
case 0x300a0350:return VR::CS;
case 0x300a0352:return VR::SH;
case 0x300a0354:return VR::LO;
case 0x300a0356:return VR::FL;
case 0x300a0358:return VR::FL;
case 0x300a035a:return VR::FL;
case 0x300a0360:return VR::SQ;
case 0x300a0362:return VR::LO;
case 0x300a0364:return VR::FL;
case 0x300a0366:return VR::FL;
case 0x300a0370:return VR::SQ;
case 0x300a0372:return VR::LO;
case 0x300a0374:return VR::FL;
case 0x300a0380:return VR::SQ;
case 0x300a0382:return VR::FL;
case 0x300a0384:return VR::FL;
case 0x300a0386:return VR::FL;
case 0x300a0388:return VR::FL;
case 0x300a038a:return VR::FL;
case 0x300a0390:return VR::SH;
case 0x300a0392:return VR::IS;
case 0x300a0394:return VR::FL;
case 0x300a0396:return VR::FL;
case 0x300a0398:return VR::FL;
case 0x300a039a:return VR::IS;
case 0x300a03a0:return VR::SQ;
case 0x300a03a2:return VR::SQ;
case 0x300a03a4:return VR::SQ;
case 0x300a03a6:return VR::SQ;
case 0x300a03a8:return VR::SQ;
case 0x300a03aa:return VR::SQ;
case 0x300a03ac:return VR::SQ;
case 0x300a0401:return VR::SQ;
case 0x300a0402:return VR::ST;
case 0x300a0410:return VR::SQ;
case 0x300a0412:return VR::FL;
case 0x300a0420:return VR::SQ;
case 0x300a0421:return VR::SH;
case 0x300a0422:return VR::ST;
case 0x300a0423:return VR::CS;
case 0x300a0424:return VR::IS;
case 0x300a0431:return VR::SQ;
case 0x300a0432:return VR::CS;
case 0x300a0433:return VR::FL;
case 0x300a0434:return VR::FL;
case 0x300a0435:return VR::FL;
case 0x300a0436:return VR::FL;
case 0x300c0002:return VR::SQ;
case 0x300c0004:return VR::SQ;
case 0x300c0006:return VR::IS;
case 0x300c0007:return VR::IS;
case 0x300c0008:return VR::DS;
case 0x300c0009:return VR::DS;
case 0x300c000a:return VR::SQ;
case 0x300c000c:return VR::IS;
case 0x300c000e:return VR::IS;
case 0x300c0020:return VR::SQ;
case 0x300c0022:return VR::IS;
case 0x300c0040:return VR::SQ;
case 0x300c0042:return VR::SQ;
case 0x300c0050:return VR::SQ;
case 0x300c0051:return VR::IS;
case 0x300c0055:return VR::SQ;
case 0x300c0060:return VR::SQ;
case 0x300c006a:return VR::IS;
case 0x300c0080:return VR::SQ;
case 0x300c00a0:return VR::IS;
case 0x300c00b0:return VR::SQ;
case 0x300c00c0:return VR::IS;
case 0x300c00d0:return VR::IS;
case 0x300c00e0:return VR::IS;
case 0x300c00f0:return VR::IS;
case 0x300c00f2:return VR::SQ;
case 0x300c00f4:return VR::IS;
case 0x300c00f6:return VR::IS;
case 0x300c0100:return VR::IS;
case 0x300c0102:return VR::IS;
case 0x300c0104:return VR::IS;
case 0x300e0002:return VR::CS;
case 0x300e0004:return VR::DA;
case 0x300e0005:return VR::TM;
case 0x300e0008:return VR::PN;
case 0x40000010:return VR::LT;
case 0x40004000:return VR::LT;
case 0x40080040:return VR::SH;
case 0x40080042:return VR::LO;
case 0x40080050:return VR::SQ;
case 0x400800ff:return VR::CS;
case 0x40080100:return VR::DA;
case 0x40080101:return VR::TM;
case 0x40080102:return VR::PN;
case 0x40080103:return VR::LO;
case 0x40080108:return VR::DA;
case 0x40080109:return VR::TM;
case 0x4008010a:return VR::PN;
case 0x4008010b:return VR::ST;
case 0x4008010c:return VR::PN;
case 0x40080111:return VR::SQ;
case 0x40080112:return VR::DA;
case 0x40080113:return VR::TM;
case 0x40080114:return VR::PN;
case 0x40080115:return VR::LT;
case 0x40080117:return VR::SQ;
case 0x40080118:return VR::SQ;
case 0x40080119:return VR::PN;
case 0x4008011a:return VR::LO;
case 0x40080200:return VR::SH;
case 0x40080202:return VR::LO;
case 0x40080210:return VR::CS;
case 0x40080212:return VR::CS;
case 0x40080300:return VR::ST;
case 0x40084000:return VR::ST;
case 0x40100001:return VR::CS;
case 0x40100002:return VR::CS;
case 0x40100004:return VR::SQ;
case 0x40101001:return VR::SQ;
case 0x40101004:return VR::FL;
case 0x40101005:return VR::FL;
case 0x40101006:return VR::OB;
case 0x40101007:return VR::SH;
case 0x40101008:return VR::CS;
case 0x40101009:return VR::CS;
case 0x4010100a:return VR::SQ;
case 0x40101010:return VR::US;
case 0x40101011:return VR::SQ;
case 0x40101012:return VR::CS;
case 0x40101013:return VR::LT;
case 0x40101014:return VR::CS;
case 0x40101015:return VR::CS;
case 0x40101016:return VR::FL;
case 0x40101017:return VR::FL;
case 0x40101018:return VR::FL;
case 0x40101019:return VR::FL;
case 0x4010101a:return VR::SH;
case 0x4010101b:return VR::FL;
case 0x4010101c:return VR::FL;
case 0x4010101d:return VR::FL;
case 0x4010101e:return VR::SH;
case 0x4010101f:return VR::SH;
case 0x40101020:return VR::CS;
case 0x40101021:return VR::CS;
case 0x40101023:return VR::FL;
case 0x40101024:return VR::CS;
case 0x40101025:return VR::DT;
case 0x40101026:return VR::DT;
case 0x40101027:return VR::CS;
case 0x40101028:return VR::CS;
case 0x40101029:return VR::LO;
case 0x4010102a:return VR::SH;
case 0x4010102b:return VR::DT;
case 0x40101031:return VR::CS;
case 0x40101033:return VR::US;
case 0x40101034:return VR::US;
case 0x40101037:return VR::SQ;
case 0x40101038:return VR::SQ;
case 0x40101039:return VR::CS;
case 0x4010103a:return VR::CS;
case 0x40101041:return VR::DT;
case 0x40101042:return VR::CS;
case 0x40101043:return VR::FL;
case 0x40101044:return VR::CS;
case 0x40101045:return VR::SQ;
case 0x40101046:return VR::CS;
case 0x40101047:return VR::SQ;
case 0x40101048:return VR::CS;
case 0x40101051:return VR::LO;
case 0x40101052:return VR::SH;
case 0x40101053:return VR::LO;
case 0x40101054:return VR::SH;
case 0x40101055:return VR::SH;
case 0x40101056:return VR::CS;
case 0x40101058:return VR::SH;
case 0x40101059:return VR::CS;
case 0x40101060:return VR::FL;
case 0x40101061:return VR::FL;
case 0x40101062:return VR::FL;
case 0x40101064:return VR::SQ;
case 0x40101067:return VR::CS;
case 0x40101068:return VR::LT;
case 0x40101069:return VR::FL;
case 0x4010106c:return VR::OB;
case 0x4ffe0001:return VR::SQ;
case 0x50000005:return VR::US;
case 0x50000010:return VR::US;
case 0x50000020:return VR::CS;
case 0x50000022:return VR::LO;
case 0x50000030:return VR::SH;
case 0x50000040:return VR::SH;
case 0x50000103:return VR::US;
case 0x50000104:return VR::US;
case 0x50000105:return VR::US;
case 0x50000106:return VR::SH;
case 0x50000110:return VR::US;
case 0x50000112:return VR::US;
case 0x50000114:return VR::US;
case 0x50001001:return VR::CS;
case 0x50002000:return VR::US;
case 0x50002002:return VR::US;
case 0x50002004:return VR::US;
case 0x50002006:return VR::UL;
case 0x50002008:return VR::UL;
case 0x5000200a:return VR::UL;
case 0x5000200e:return VR::LT;
case 0x50002500:return VR::LO;
case 0x50002600:return VR::SQ;
case 0x50002610:return VR::US;
case 0x52009229:return VR::SQ;
case 0x52009230:return VR::SQ;
case 0x54000100:return VR::SQ;
case 0x54001004:return VR::US;
case 0x54001006:return VR::CS;
case 0x56000010:return VR::OF;
case 0x56000020:return VR::OF;
case 0x60000010:return VR::US;
case 0x60000011:return VR::US;
case 0x60000012:return VR::US;
case 0x60000015:return VR::IS;
case 0x60000022:return VR::LO;
case 0x60000040:return VR::CS;
case 0x60000045:return VR::LO;
case 0x60000050:return VR::SS;
case 0x60000051:return VR::US;
case 0x60000052:return VR::US;
case 0x60000060:return VR::CS;
case 0x60000061:return VR::SH;
case 0x60000062:return VR::SH;
case 0x60000063:return VR::CS;
case 0x60000066:return VR::AT;
case 0x60000068:return VR::US;
case 0x60000069:return VR::US;
case 0x60000100:return VR::US;
case 0x60000102:return VR::US;
case 0x60000110:return VR::CS;
case 0x60000200:return VR::US;
case 0x60000800:return VR::CS;
case 0x60000802:return VR::US;
case 0x60000803:return VR::AT;
case 0x60000804:return VR::US;
case 0x60001001:return VR::CS;
case 0x60001100:return VR::US;
case 0x60001101:return VR::US;
case 0x60001102:return VR::US;
case 0x60001103:return VR::US;
case 0x60001200:return VR::US;
case 0x60001201:return VR::US;
case 0x60001202:return VR::US;
case 0x60001203:return VR::US;
case 0x60001301:return VR::IS;
case 0x60001302:return VR::DS;
case 0x60001303:return VR::DS;
case 0x60001500:return VR::LO;
case 0x60004000:return VR::LT;
case 0x7fe00020:return VR::OW;
case 0x7fe00030:return VR::OW;
case 0x7fe00040:return VR::OW;
case 0x7f000011:return VR::US;
case 0x7f000020:return VR::OW;
case 0x7f000030:return VR::OW;
case 0x7f000040:return VR::OW;
case 0xfffafffa:return VR::SQ;
case 0xfffcfffc:return VR::OB;

default:
return VR::INVALID;
}
}
    
} // end namespace gdcm
